/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import 'cypress-real-events';
import { AdminUserE2E } from '../../model/util';
import { exist } from '../../support/cypress.util';

export class BenutzerE2EComponent {
  private readonly benutzerHinzufuegenButton: string = 'add-user-button';
  private readonly userEntry: string = 'user-entry-';
  private readonly userVorname: string = 'Vorname-text-input';
  private readonly userNachname: string = 'Nachname-text-input';
  private readonly userBenutzername: string = 'Benutzername-text-input';
  private readonly userMail: string = 'E-Mail-text-input';
  private readonly adminCheckbox: string = 'Admin-checkbox-editor';
  private readonly loeschenCheckbox: string = 'Loschen-checkbox-editor';
  private readonly userCheckbox: string = 'User-checkbox-editor';
  private readonly postCheckbox: string = 'Poststelle-checkbox-editor';
  private readonly saveButton: string = 'save-button';
  private readonly organisationsEinheitCheckbox: string = '-checkbox-editor';

  public getHinzufuegenButton(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.benutzerHinzufuegenButton);
  }

  public hinzufuegenButtonIsVisible(): void {
    exist(this.getHinzufuegenButton());
  }

  public clickAddUser(): void {
    this.getHinzufuegenButton().click();
  }

  public addUser(user: AdminUserE2E): void {
    this.enterVorname(user.vorname);
    this.enterNachname(user.nachname);
    this.enterBenutzername(user.benutzername);
    this.enterMail(user.email);

    if (user.isAdmin) {
      this.clickAdminCheckbox();
    }
    if (user.isUser) {
      this.clickUserCheckbox();
    }
    if (user.isLoeschen) {
      this.clickLoeschenCheckbox();
    }
    if (user.isPoststelle) {
      this.clickPostCheckbox();
    }

    if (user.organisationseinheiten) {
      for (const einheit of user.organisationseinheiten) {
        this.clickOrganisationsEinheitCheckbox(einheit);
      }
    }
    this.saveUser();
  }

  public getUserEntry(user: string): Cypress.Chainable<Element> {
    user = this.userEntry + user;
    return cy.getTestElement(user);
  }

  public clickUserEntry(user: string): void {
    this.getUserEntry(user).click();
  }

  public stringExistsInUserEntry(phrase: string, user: string): void {
    this.getUserEntry(user).within(() => {
      exist(cy.contains(phrase));
    });
  }

  public getVornameInput(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.userVorname);
  }

  public enterVorname(vorname: string): void {
    this.getVornameInput().type(vorname);
  }

  public getNachnameInput(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.userNachname);
  }

  public enterNachname(nachname: string): void {
    this.getNachnameInput().type(nachname);
  }

  public getBenutzernameInput(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.userBenutzername);
  }

  public enterBenutzername(benutzername: string): void {
    this.getBenutzernameInput().type(benutzername);
  }

  public getMailInput(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.userMail);
  }

  public enterMail(mail: string): void {
    this.getMailInput().type(mail);
  }

  public getAdminCheckbox(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.adminCheckbox);
  }

  public clickAdminCheckbox(): void {
    this.getAdminCheckbox().click();
  }

  public getLoeschenCheckbox() {
    return cy.getTestElement(this.loeschenCheckbox);
  }

  public clickLoeschenCheckbox(): void {
    this.getLoeschenCheckbox().click();
  }

  public getUserCheckbox(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.userCheckbox);
  }

  public clickUserCheckbox(): void {
    this.getUserCheckbox().click();
  }

  public getPostCheckbox(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.postCheckbox);
  }

  public clickPostCheckbox(): void {
    this.getPostCheckbox().click();
  }

  public getSaveButton(): Cypress.Chainable<Element> {
    return cy.getTestElement(this.saveButton);
  }

  public saveUser(): void {
    this.getSaveButton().click();
  }

  public getOrganisationsEinheitCheckbox(einheit: string): Cypress.Chainable<Element> {
    return cy.getTestElement(einheit + this.organisationsEinheitCheckbox);
  }

  public clickOrganisationsEinheitCheckbox(einheit: string): void {
    this.getOrganisationsEinheitCheckbox(einheit).click();
  }
}
