/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElement, getTestElement } from '../../support/cypress-helper';
import { ExpansionPanelE2Eomponent } from '../ui/expansion-panel.e2e.component';
import {
  VorgangFormularDatenHistorieE2EComponent,
  VorgangFormularDatenHistorieItemE2EComponent,
} from './vorgang.formular-daten.historie.e2e.component';

export class VorgangFormularDatenE2EComponent {
  private readonly locatorRoot: string = 'formulardaten-panel';
  private readonly locatorDateien: string = 'dateien';
  private readonly locatorMetadaten: string = 'metadaten';
  private readonly locatorAntragdaten: string = 'antragdaten';
  private readonly locatorTabset: string = 'div[role=tab]';

  private readonly vorgangFormPanelContainer: ExpansionPanelE2Eomponent =
    new ExpansionPanelE2Eomponent();
  private readonly historieContainer: VorgangFormularDatenHistorieE2EComponent =
    new VorgangFormularDatenHistorieE2EComponent();

  private readonly fileListHeader: string = 'file-list';
  private readonly attachmentListHeader: string = 'attachment-list';

  private readonly antragdatenTab: number = 0;
  private readonly metadatenTab: number = 9;
  private readonly representationTab: number = 9;
  private readonly dateienTab: number = 1;
  private readonly historieTab: number = 2;

  public getRoot() {
    return cy.getTestElement(this.locatorRoot);
  }

  public getExpansionPanelContainer(): ExpansionPanelE2Eomponent {
    return this.vorgangFormPanelContainer;
  }

  public getAntragdatenTab() {
    return this.getTabsetElement().eq(this.antragdatenTab);
  }

  public getMetadatenTab() {
    return this.getTabsetElement().eq(this.metadatenTab);
  }

  public getRepresentationTab() {
    return this.getTabsetElement().eq(this.representationTab);
  }

  public getDateienTab() {
    return this.getTabsetElement().eq(this.dateienTab);
  }

  public getHistorieTab() {
    return this.getTabsetElement().eq(this.historieTab);
  }

  private getTabsetElement() {
    return getElement(this.locatorTabset);
  }

  public getMetadaten() {
    return getTestElement(this.locatorMetadaten);
  }

  public getAntragdaten() {
    return getTestElement(this.locatorAntragdaten);
  }

  public getDateien() {
    return getTestElement(this.locatorDateien);
  }

  public getTabset() {
    return getTestElement(this.locatorTabset);
  }

  public getHistorieContainer(): VorgangFormularDatenHistorieE2EComponent {
    return this.historieContainer;
  }

  public getHistorieItemByIndex(index: number): VorgangFormularDatenHistorieItemE2EComponent {
    return this.getHistorieContainer().getListItemByIndex(index);
  }

  public getFileListHeader() {
    return getTestElement(this.fileListHeader);
  }

  public getAttachmentListHeader() {
    return getTestElement(this.attachmentListHeader);
  }

  public getFileElementByName(fileName: string) {
    fileName = fileName.replace(/\./g, '') + '-file-item';
    return getTestElement(fileName);
  }
}
