import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { exist, notExist } from '../../../support/cypress.util';
import { loginAsPeter, loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgaenge } from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('Vorgang weiterleiten innerhalb der OzgCloud', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const vorgangPage: VorgangPage = new VorgangPage();
  const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();

  const vorgangWeiterleiten: VorgangE2E = { ...createVorgang(), name: 'Weiterleitung' };

  after(() => {
    dropCollections();
  });

  describe('For Sabine', () => {
    before(() => {
      initVorgaenge([vorgangWeiterleiten]);

      loginAsSabine();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    it('should display Weiterleiten button in Status Neu', () => {
      vorgangList.getListItem(vorgangWeiterleiten.name).getRoot().click();
      waitForSpinnerToDisappear();

      exist(vorgangFormularButtons.getForwardButton());
    });

    it('should not display Weiterleiten button in Status Angenommen', () => {
      vorgangFormularButtons.getAnnehmenButton().click();
      waitForSpinnerToDisappear();

      notExist(vorgangFormularButtons.getForwardButton());
    });

    it('should not display Weiterleiten button in Status In Bearbeitung', () => {
      vorgangFormularButtons.getBearbeitenButton().click();
      waitForSpinnerToDisappear();

      notExist(vorgangFormularButtons.getForwardButton());
    });
  });

  describe('For Peter', () => {
    before(() => {
      initVorgaenge([vorgangWeiterleiten]);

      loginAsPeter();

      waitForSpinnerToDisappear();
      exist(vorgangList.getRoot());
    });

    it('should not display Weiterleiten button in Status In Neu', () => {
      vorgangList.getListItem(vorgangWeiterleiten.name).getRoot().click();
      waitForSpinnerToDisappear();

      notExist(vorgangFormularButtons.getForwardButton());
    });
  });
});
