/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ClientE2E, DateE2E, ObjectIdE2E } from './util';

export enum BinaryFileSnackbarMessageE2E {
  ATTACHMENT_NOT_ADDED = 'Anhänge größer {size} können nicht hinzugefügt werden.',
}

export enum BinaryFileFieldE2E {
  WIEDERVORLAGE_ATTACHMENT = 'wiedervorlageAttachment',
  POSTFACH_NACHRICHT_ATTACHMENT = 'PostfachNachrichtAttachment',
  VORGANG_ATTACHMENT = 'vorgangAttachment',
}

export class FileDataE2E {
  _id: string;
  vendorId: string;
  name: string;
  size: number;
  contentType: string;
}

export interface CreateFileDataE2E {
  file: GridFsFileE2E;
  chunks: GridFsChunkE2E[];
  ozgcloudFile: OzgCloudFileE2E;
}

export interface GridFsFileE2E {
  _id: ObjectIdE2E;
  filename: string;
  length: number;
  chunkSize: number;
  uploadDate: DateE2E;
  metadata: GridFsFileMetadataE2E;
}

export interface GridFsFileMetadataE2E {
  vorgangId: string;
  client: ClientE2E;
  fieldName: BinaryFileFieldE2E;
  name: string;
  createdBy: string;
}

export interface GridFsChunkE2E {
  _id: ObjectIdE2E;
  files_id: ObjectIdE2E;
  n: number;
  data: BinaryBase64E2E;
}

export class BinaryBase64E2E {
  $binary: { base64: string };
}

export interface InitOzgCloudFileTaskData {
  collection: string;
  data: OzgCloudFileE2E[];
}

export class OzgCloudFileE2E {
  _id: ObjectIdE2E;
  client: string;
  contentId: string;
  contentType: string;
  createdBy: string;
  fieldName: string;
  name: string;
  size: number;
  version: number;
  vorgangId: string;
}
