import { ConfigurationResource, ConfigurationService } from '@admin-client/configuration-shared';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { getMockComponent, mock, Mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { createConfigurationResource } from '../../../../configuration-shared/test/configuration';
import { MenuContainerComponent } from './menu-container.component';
import { MenuComponent } from './menu/menu.component';

describe('MenuContainerComponent', () => {
  let component: MenuContainerComponent;
  let fixture: ComponentFixture<MenuContainerComponent>;

  let configurationService: Mock<ConfigurationService>;

  const configurationStateResource: StateResource<ConfigurationResource> = createStateResource(createConfigurationResource());

  beforeEach(async () => {
    configurationService = { ...mock(ConfigurationService), get: jest.fn().mockReturnValue(of(configurationStateResource)) };

    await TestBed.configureTestingModule({
      imports: [MenuContainerComponent],
      declarations: [MockComponent(MenuComponent)],
      providers: [
        {
          provide: ConfigurationService,
          useValue: configurationService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(MenuContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call service', () => {
      component.ngOnInit();

      expect(configurationService.get).toHaveBeenCalled();
    });
  });

  it('should call menu', () => {
    const menu: MenuComponent = getMockComponent(fixture, MenuComponent);

    expect(menu.configurationStateResource).toBe(configurationStateResource);
  });
});
