/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { PostfachResource } from '@admin-client/postfach-shared';
import { createEmptyStateResource, isNotNil, StateResource } from '@alfa-client/tech-shared';
import { CommonModule } from '@angular/common';
import { Component, inject, Input } from '@angular/core';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Resource } from '@ngxp/rest';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { Observable, of } from 'rxjs';
import { PostfachSignaturComponent } from './postfach-signatur/postfach-signatur.component';
import { PostfachFormService } from './postfach.formservice';

@Component({
  selector: 'admin-postfach-form',
  templateUrl: './postfach-form.component.html',
  providers: [PostfachFormService],
  standalone: true,
  imports: [CommonModule, FormsModule, ReactiveFormsModule, PostfachSignaturComponent, ButtonWithSpinnerComponent],
})
export class PostfachFormComponent {
  public formService = inject(PostfachFormService);

  submitInProgress$: Observable<StateResource<Resource>> = of(createEmptyStateResource<Resource>());

  @Input() set postfachStateResource(stateResource: StateResource<PostfachResource>) {
    this.updatePostfachResource(stateResource.resource);
  }

  updatePostfachResource(postfachRessource: PostfachResource): void {
    if (isNotNil(postfachRessource)) {
      this.formService.patch(postfachRessource.settingBody);
    }
  }

  protected readonly PostfachFormService = PostfachFormService;

  public submit(): void {
    this.submitInProgress$ = this.formService.submit();
  }
}
