/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { StateResource, createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { TestBed } from '@angular/core/testing';
import { singleCold } from 'libs/tech-shared/test/marbles';
import { Observable, of } from 'rxjs';
import { createSettingItemResource, createSettingsListResource } from '../../test/settings';
import { SettingListResourceService } from './settings-resource.service';
import { SettingItemResource, SettingListResource, SettingName } from './settings.model';
import { SettingsService } from './settings.service';

describe('SettingsService', () => {
  let service: SettingsService;
  let settingListResourceService: Mock<SettingListResourceService>;

  beforeEach(() => {
    settingListResourceService = mock(SettingListResourceService);

    TestBed.configureTestingModule({
      providers: [SettingsService, { provide: SettingListResourceService, useValue: settingListResourceService }],
    });

    service = TestBed.inject(SettingsService);
  });

  it('should create', () => {
    expect(service).toBeTruthy();
  });

  describe('get by setting name', () => {
    const settingItemName: SettingName = <SettingName>'DUMMY';
    const settingItemResource: SettingItemResource<unknown> = { ...createSettingItemResource(), name: settingItemName };
    const settingItemStateResource: StateResource<SettingItemResource<unknown>> = createStateResource(settingItemResource);
    const settingsListResource: StateResource<SettingListResource> = createStateResource(
      createSettingsListResource([settingItemResource]),
    );

    beforeEach(() => {
      settingListResourceService.getList = jest.fn().mockReturnValue(of(settingsListResource));
    });

    it('should call resource service', () => {
      service.get(settingItemName);

      expect(settingListResourceService.getList).toHaveBeenCalled();
    });

    it('should return null for non existing setting item resource', () => {
      const emptySettingsListResource: StateResource<SettingListResource> = createStateResource(
        createSettingsListResource([createSettingItemResource()]),
      );
      settingListResourceService.getList = jest.fn().mockReturnValue(singleCold(emptySettingsListResource));

      const settingItemStateResource$: Observable<StateResource<SettingItemResource<unknown>>> = service.get(settingItemName);

      expect(settingItemStateResource$).toBeObservable(singleCold(createEmptyStateResource()));
    });

    it('should return item resource as setting item resource', () => {
      settingListResourceService.getList = jest.fn().mockReturnValue(singleCold(settingsListResource));

      const settingItemStateResource$: Observable<StateResource<SettingItemResource<unknown>>> = service.get(settingItemName);

      expect(settingItemStateResource$).toBeObservable(singleCold(settingItemStateResource));
    });
  });
});
