import { ADMIN_FORMSERVICE } from '@admin-client/shared';
import { AbstractFormService, createStateResource, StateResource } from '@alfa-client/tech-shared';
import { dispatchEventFromFixture, getMockComponent, Mock, MockEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { Resource } from '@ngxp/rest';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { getDataTestIdAttributeOf } from 'libs/tech-shared/test/data-test';
import { singleCold } from 'libs/tech-shared/test/marbles';
import { createDummyResource } from 'libs/tech-shared/test/resource';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { AdminSaveButtonComponent } from './admin-save-button.component';

describe('AdminSaveButtonComponent', () => {
  let component: AdminSaveButtonComponent;
  let fixture: ComponentFixture<AdminSaveButtonComponent>;

  let formService: Mock<AbstractFormService<Resource>>;

  const saveButton: string = getDataTestIdAttributeOf('save-button');

  const stateResource: StateResource<Resource> = createStateResource(createDummyResource());

  beforeEach(async () => {
    formService = <any>{ submit: jest.fn().mockReturnValue(singleCold(stateResource)) };

    await TestBed.configureTestingModule({
      imports: [AdminSaveButtonComponent],
      declarations: [MockComponent(ButtonWithSpinnerComponent)],
      providers: [
        {
          provide: ADMIN_FORMSERVICE,
          useValue: formService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(AdminSaveButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('on submit', () => {
    it('should call formService', () => {
      dispatchEventFromFixture(fixture, saveButton, MockEvent.CLICK);

      expect(formService.submit).toHaveBeenCalled();
    });

    it('should assign state resource', () => {
      dispatchEventFromFixture(fixture, saveButton, MockEvent.CLICK);

      expect(component.stateResource$).toBeObservable(singleCold(stateResource));
    });
  });

  describe('button', () => {
    it('should call with stateResource', () => {
      component.stateResource$ = of(stateResource);

      fixture.detectChanges();

      const comp: ButtonWithSpinnerComponent = getMockComponent(fixture, ButtonWithSpinnerComponent);
      expect(comp.stateResource).toBe(stateResource);
    });
  });
});
