/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AggregationMappingListResource, AggregationMappingService } from '@admin-client/reporting-shared';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, mock, Mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { RoutingButtonComponent } from '@ods/component';
import { singleCold } from 'libs/tech-shared/test/marbles';
import { MockComponent } from 'ng-mocks';
import { getDataTestIdAttributeOf } from '../../../../../tech-shared/test/data-test';
import { createAggregationMappingListResource } from '../../../../reporting-shared/test/aggregation-mapping';
import { StatistikContainerComponent } from './statistik-container.component';

describe('StatistikContainerComponent', () => {
  let component: StatistikContainerComponent;
  let fixture: ComponentFixture<StatistikContainerComponent>;

  const evaluateAdditionalFieldsTestId: string = getDataTestIdAttributeOf('weitere-felder-auswerten-button');

  let aggregationMappingService: Mock<AggregationMappingService>;

  beforeEach(async () => {
    aggregationMappingService = mock(AggregationMappingService);

    await TestBed.configureTestingModule({
      imports: [StatistikContainerComponent],
      declarations: [MockComponent(RoutingButtonComponent)],
    })
      .overrideComponent(StatistikContainerComponent, {
        set: {
          providers: [
            {
              provide: AggregationMappingService,
              useValue: aggregationMappingService,
            },
          ],
        },
      })
      .compileComponents();

    fixture = TestBed.createComponent(StatistikContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('weiter felder auswerten button', () => {
      it('should exists', () => {
        fixture.detectChanges();

        existsAsHtmlElement(fixture, evaluateAdditionalFieldsTestId);
      });
    });
  });

  describe('on init', () => {
    const stateResource: StateResource<AggregationMappingListResource> = createStateResource(
      createAggregationMappingListResource(),
    );

    beforeEach(() => {
      aggregationMappingService.getList.mockReturnValue(singleCold(stateResource));
    });

    it('should call service to get list', () => {
      component.ngOnInit();

      expect(aggregationMappingService.getList).toHaveBeenCalled();
    });

    it('should assign stateResource', () => {
      component.ngOnInit();

      expect(component.listStateResource$).toBeObservable(singleCold(stateResource));
    });
  });
});
