/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AggregationMappingResource, AggregationMappingService } from '@admin-client/reporting-shared';
import { EMPTY_STRING, StateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock } from '@alfa-client/test-utils';
import { TestBed } from '@angular/core/testing';
import { FormArray, FormControl, FormGroup } from '@angular/forms';
import { createAggregationMapping, createAggregationMappingResource } from 'libs/admin/reporting-shared/test/aggregation-mapping';
import { of } from 'rxjs';
import { StatistikFieldsFormService } from './statistik-fields.formservice';

describe('StatistikFieldsFormService', () => {
  let formService: StatistikFieldsFormService;

  let service: Mock<AggregationMappingService>;

  beforeEach(() => {
    service = mock(AggregationMappingService);

    TestBed.configureTestingModule({
      providers: [StatistikFieldsFormService, { provide: AggregationMappingService, useValue: service }],
    });

    formService = TestBed.inject(StatistikFieldsFormService);
  });

  it('should create', () => {
    expect(formService).toBeTruthy();
  });

  describe('on do submit', () => {
    const stateResource: StateResource<AggregationMappingResource> = createStateResource(createAggregationMappingResource());

    beforeEach(() => {
      service.create.mockReturnValue(of(stateResource));
    });

    it('should call service', () => {
      formService.form = <any>createAggregationMapping();

      formService.submit();

      expect(service.create).toHaveBeenCalledWith(formService.form.value);
    });
  });

  describe('add mapping', () => {
    it('should add mapping control', () => {
      formService.addMapping();

      const mappingFormArray: FormArray = <FormArray>formService.form.controls[StatistikFieldsFormService.FIELD_MAPPINGS];
      expect(mappingFormArray).toHaveLength(2);
      expect(mappingFormArray.controls[0].value).toEqual({ sourcePath: EMPTY_STRING });
    });
  });

  describe('remove mapping', () => {
    it('should remove mapping control', () => {
      (<FormArray>formService.form.controls[StatistikFieldsFormService.FIELD_MAPPINGS]).push(
        new FormGroup({ sourcePath: new FormControl('controlToRemove') }),
      );

      formService.removeMapping(1);

      const mappingFormArray: FormArray = <FormArray>formService.form.controls[StatistikFieldsFormService.FIELD_MAPPINGS];
      expect(mappingFormArray).toHaveLength(1);
      expect(mappingFormArray.controls[0].value).toEqual({ sourcePath: EMPTY_STRING });
    });
  });

  describe('get mappings', () => {
    it('should return mappings as array', () => {
      const mappings: FormArray = formService.mappings;

      expect(mappings).toHaveLength(1);
      expect(mappings.controls[0].value).toEqual({ sourcePath: EMPTY_STRING });
    });
  });
});
