import { AggregationMappingResource, AggregationMappingService } from '@admin-client/reporting-shared';
import { AbstractFormService, EMPTY_STRING, StateResource } from '@alfa-client/tech-shared';
import { inject, Injectable } from '@angular/core';
import { FormArray, FormControl, FormGroup, UntypedFormGroup } from '@angular/forms';
import { Observable } from 'rxjs';

@Injectable()
export class StatistikFieldsFormService extends AbstractFormService<AggregationMappingResource> {
  private service = inject(AggregationMappingService);

  public static readonly FIELD_FORM_IDENTIFIER: string = 'formIdentifier';
  public static readonly FIELD_FORM_ENGINE_NAME: string = 'formEngineName';
  public static readonly FIELD_FORM_ID: string = 'formId';

  public static readonly FIELD_MAPPINGS: string = 'mappings';

  protected initForm(): UntypedFormGroup {
    return this.formBuilder.group({
      [StatistikFieldsFormService.FIELD_FORM_IDENTIFIER]: this.formBuilder.group({
        [StatistikFieldsFormService.FIELD_FORM_ENGINE_NAME]: new FormControl(EMPTY_STRING),
        [StatistikFieldsFormService.FIELD_FORM_ID]: new FormControl(EMPTY_STRING),
      }),
      [StatistikFieldsFormService.FIELD_MAPPINGS]: new FormArray([this.createArrayControl()]),
    });
  }

  protected doSubmit(): Observable<StateResource<AggregationMappingResource>> {
    return this.service.create(this.getFormValue());
  }

  protected getPathPrefix(): string {
    return 'settingBody';
  }

  public addMapping(): void {
    this.mappings.push(this.createArrayControl());
  }

  private createArrayControl(): FormGroup {
    return new FormGroup({ sourcePath: new FormControl(EMPTY_STRING) });
  }

  public removeMapping(index: number): void {
    this.mappings.removeAt(index);
  }

  public get mappings(): FormArray {
    return this.form.controls[StatistikFieldsFormService.FIELD_MAPPINGS] as FormArray;
  }
}
