/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ROUTES } from '@admin-client/shared';
import { User } from '@admin-client/user-shared';
import { createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { getMockComponent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { RoutingButtonComponent } from '@ods/component';
import { MockComponent } from 'ng-mocks';
import { createUser } from '../../../../../user-shared/test/user';
import { UserListComponent } from './user-list.component';
import { UserComponent } from './user/user.component';

describe('UsersListComponent', () => {
  let component: UserListComponent;
  let fixture: ComponentFixture<UserListComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [UserListComponent],
      declarations: [MockComponent(RoutingButtonComponent), MockComponent(UserComponent)],
    }).compileComponents();

    fixture = TestBed.createComponent(UserListComponent);
    component = fixture.componentInstance;
    component.usersStateResource = createEmptyStateResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    it('should render routing button', () => {
      const routingButton: RoutingButtonComponent = getMockComponent(fixture, RoutingButtonComponent);
      expect(routingButton.linkPath).toBe(ROUTES.BENUTZER_NEU);
    });

    it('should render UserComponent if user in resource', () => {
      const user: User = createUser();
      component.usersStateResource = createStateResource([user]);

      fixture.detectChanges();

      const userComponent: UserComponent = getMockComponent(fixture, UserComponent);
      expect(userComponent.user).toEqual(user);
    });
  });
});
//todo: fix datei herstellen
