import { getMockComponent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ListItemComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { ToUserRolesPipe } from '../../../../../../user-shared/src/lib/to-user-roles.pipe';
import { createUser } from '../../../../../../user-shared/test/user';
import { UserDataComponent } from './user-data/user-data.component';
import { UserOrganisationsEinheitenComponent } from './user-organisations-einheiten/user-organisations-einheiten.component';
import { UserRolesComponent } from './user-roles/user-roles.component';
import { UserComponent } from './user.component';

describe('UserComponent', () => {
  let component: UserComponent;
  let fixture: ComponentFixture<UserComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        UserComponent,
        MockComponent(ListItemComponent),
        MockComponent(UserRolesComponent),
        MockComponent(UserDataComponent),
        MockComponent(UserOrganisationsEinheitenComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(UserComponent);
    component = fixture.componentInstance;
    component.user = createUser();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    it('should render ListItemComponent', () => {
      const listItem: ListItemComponent = getMockComponent(fixture, ListItemComponent);
      expect(listItem.path).toBe(component.user.id);
    });

    it('should render user roles', () => {
      const toUserRolesPipe = new ToUserRolesPipe();

      const userRoles: UserRolesComponent = getMockComponent(fixture, UserRolesComponent);
      expect(userRoles.roles).toEqual(toUserRolesPipe.transform(component.user));
    });

    it('should render user data', () => {
      const userData: UserDataComponent = getMockComponent(fixture, UserDataComponent);
      expect(userData.user).toBe(component.user);
    });

    it('should render user organisationsEinheiten', () => {
      const userOrganisationsEinheiten: UserOrganisationsEinheitenComponent = getMockComponent(
        fixture,
        UserOrganisationsEinheitenComponent,
      );

      expect(userOrganisationsEinheiten.organisationsEinheiten).toBe(component.user.groups);
    });
  });
});
