/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  CommandOrder,
  CommandResource,
  CommandService,
  CreateCommand,
} from '@alfa-client/command-shared';
import { createStateResource, EMPTY_STRING, StateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Store } from '@ngrx/store';
import { Resource } from '@ngxp/rest';
import { createCommandResource, createCreateCommand } from 'libs/command-shared/test/command';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { Subject } from 'rxjs';
import { BescheidFacade } from './bescheid.facade';

describe('BescheidFacade', () => {
  const store: Mock<Store> = mock(Store);

  let facade: BescheidFacade;
  let commandService: Mock<CommandService>;
  let selectSubj: Subject<StateResource<Resource>>;

  beforeEach(() => {
    commandService = mock(CommandService);

    selectSubj = new Subject();
    store.select.mockReturnValue(selectSubj);

    facade = new BescheidFacade(useFromMock(store), useFromMock(commandService));
  });

  describe('getBescheidCommand', () => {
    it('should return selected value', (done) => {
      const expected: StateResource<CommandResource> = createStateResource(createCommandResource());

      facade.getBescheidCommand().subscribe((userSettings) => {
        expect(userSettings).toBe(expected);
        done();
      });

      selectSubj.next(expected);
    });
  });

  describe('createBescheidDraft', () => {
    const createCommand: CreateCommand = createCreateCommand(CommandOrder.CREATE_BESCHEID);

    it('should create command', () => {
      const vorgang: VorgangWithEingangResource = createVorgangWithEingangResource([
        VorgangWithEingangLinkRel.CREATE_BESCHEID_DRAFT,
      ]);

      facade.createBescheidDraft(vorgang, createCommand);

      expect(commandService.createCommandByProps).toHaveBeenCalledWith({
        resource: vorgang,
        linkRel: VorgangWithEingangLinkRel.CREATE_BESCHEID_DRAFT,
        command: createCommand,
        snackBarMessage: EMPTY_STRING,
      });
    });
  });
});
