/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import { CommandResource } from '@alfa-client/command-shared';
import { createEmptyStateResource, HttpError, ListResource, StateResource } from '@alfa-client/tech-shared';
import { Resource, ResourceUri } from '@ngxp/rest';

export enum BescheidStatus {
  DRAFT = 'DRAFT',
  SENT = 'SENT',
}

export interface Bescheid {
  status: BescheidStatus;
  beschiedenAm: string;
  bewilligt: boolean | string;
  sendBy?: BescheidSendBy;
  bescheidDocument?: string;
  attachments?: string[];
  nachrichtText?: string;
  nachrichtSubject?: string;
}

export interface BescheidResource extends Bescheid, Resource {}

export enum BescheidSendBy {
  MANUAL = 'MANUAL',
  NACHRICHT = 'NACHRICHT',
}

export interface BescheidListResource extends ListResource {}

export interface UploadFileInProgress {
  loading: boolean;
  fileName?: string;
  error?: HttpError;
}

export enum BescheidWizardStep {
  AntragBescheiden = 1,
  DokumenteHochladen = 2,
  BescheidVersenden = 3,
}

export interface BescheidWizardDialogResult {
  reloadVorgang: boolean;
}

export interface BescheidDocument {
  upload: UploadFileInProgress;
  create: StateResource<CommandResource>;
  documentUri?: ResourceUri;
  resource?: BinaryFileResource;
}

export function createEmptyBescheidDocument(): BescheidDocument {
  return {
    upload: createEmptyUploadInProgress(),
    create: createEmptyStateResource(),
  };
}

export interface BescheidAttachments {
  upload: UploadFileInProgress;
  uploadStateResource: StateResource<BinaryFileResource>;
  items: BinaryFileResource[];
}

export function createEmptyBescheidAttachments(): BescheidAttachments {
  return {
    upload: createEmptyUploadInProgress(),
    uploadStateResource: createEmptyStateResource(),
    items: [],
  };
}

export function createEmptyUploadInProgress(): UploadFileInProgress {
  return {
    loading: false,
    fileName: null,
  };
}

export interface Wizard {
  activeStep: BescheidWizardStep;
  sendBy: BescheidSendBy;
  canBeSend: boolean;
  bescheidCreated: boolean;
  empfaenger?: string;
}

export function createInitialWizard(): Wizard {
  return {
    activeStep: BescheidWizardStep.AntragBescheiden,
    sendBy: BescheidSendBy.NACHRICHT,
    canBeSend: true,
    bescheidCreated: false,
  };
}
