/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { existsAsHtmlElement, getElementFromFixtureByType, Mock, mock, triggerEvent, useFromMock } from '@alfa-client/test-utils';
import { EventEmitter } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidResource } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { createVorgangWithEingangResource } from '../../../../../../vorgang-shared/test/vorgang';
import { StepContentLayoutComponent } from '../step-content-layout/step-content-layout.component';
import { BescheidWizardStepTitleComponent } from '../step-title/bescheid-wizard-step-title.component';
import { BescheidWizardStepperComponent } from '../stepper/bescheid-wizard-stepper.component';
import { BescheidWizardSummaryComponent } from '../summary/bescheid-wizard-summary.component';
import { BescheidWizardAbschliessenButtonComponent } from './abschliessen-button/bescheid-wizard-abschliessen-button.component';
import { BescheidWizardAntragBescheidenContainerComponent } from './bescheid-wizard-antrag-bescheiden-container.component';
import { BescheidWizardAntragBescheidenFormComponent } from './form/bescheid-wizard-antrag-bescheiden-form.component';
import { BescheidWizardAntragBescheidenSummaryComponent } from './summary/bescheid-wizard-antrag-bescheiden-summary.component';

describe('BescheidWizardAntragBescheidenComponent', () => {
  let component: BescheidWizardAntragBescheidenContainerComponent;
  let fixture: ComponentFixture<BescheidWizardAntragBescheidenContainerComponent>;

  const wizardStepTitle: string = getDataTestIdOf('wizard-step-title');
  const antragBescheidenForm: string = getDataTestIdOf('antrag-bescheiden-form');
  const abschliessenButton: string = getDataTestIdOf('wizard-abschliessen-button');
  const antragBescheidenSummary: string = getDataTestIdOf('antrag-bescheiden-summary');

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardAntragBescheidenContainerComponent,
        MockComponent(StepContentLayoutComponent),
        MockComponent(BescheidWizardStepTitleComponent),
        MockComponent(BescheidWizardAntragBescheidenFormComponent),
        MockComponent(BescheidWizardSummaryComponent),
        MockComponent(BescheidWizardAntragBescheidenSummaryComponent),
        MockComponent(BescheidWizardAbschliessenButtonComponent),
        MockComponent(BescheidWizardStepperComponent),
      ],
      providers: [
        {
          provide: BescheidService2,
          useValue: bescheidService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardAntragBescheidenContainerComponent);
    component = fixture.componentInstance;
    component.vorgangAbgeschlossen = useFromMock(mock(EventEmitter<void>));
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('wizard step title', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, wizardStepTitle);
      });
    });

    describe('antrag bescheiden form', () => {
      function getElementComponent(): BescheidWizardAntragBescheidenFormComponent {
        return getElementFromFixtureByType(fixture, BescheidWizardAntragBescheidenFormComponent);
      }

      it('should exists', () => {
        existsAsHtmlElement(fixture, antragBescheidenForm);
      });

      it('should have been called with inputs', () => {
        component.vorgangWithEingangResource = createVorgangWithEingangResource();
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        expect(getElementComponent().vorgangWithEingangResource).toBe(component.vorgangWithEingangResource);
        expect(getElementComponent().bescheidResource).toBe(component.bescheidResource);
      });

      describe('output', () => {
        describe('weiterClickEmitter', () => {
          it('should call handler', () => {
            component.onWeiterClick = jest.fn();

            triggerEvent({ fixture, name: 'weiterClickEmitter', elementSelector: antragBescheidenForm });

            expect(component.onWeiterClick).toHaveBeenCalled();
          });
        });
      });
    });

    describe('abschliessen button', () => {
      function getElementComponent(): BescheidWizardAbschliessenButtonComponent {
        return getElementFromFixtureByType(fixture, BescheidWizardAbschliessenButtonComponent);
      }

      it('should exists', () => {
        existsAsHtmlElement(fixture, abschliessenButton);
      });

      it('should have been called with inputs', () => {
        component.vorgangWithEingangResource = createVorgangWithEingangResource();
        component.bescheidResource = createBescheidResource();

        fixture.detectChanges();

        expect(getElementComponent().vorgangWithEingangResource).toBe(component.vorgangWithEingangResource);
        expect(getElementComponent().bescheidResource).toBe(component.bescheidResource);
      });

      describe('output', () => {
        it('should call handler', () => {
          triggerEvent({ fixture, name: 'vorgangAbgeschlossen', elementSelector: abschliessenButton });

          expect(component.vorgangAbgeschlossen.emit).toHaveBeenCalled();
        });
      });
    });

    describe('antrag bescheiden summary', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, antragBescheidenSummary);
      });
    });
  });
});
