import { BescheidAttachments, createEmptyBescheidAttachments, createEmptyUploadInProgress } from '@alfa-client/bescheid-shared';
import { BinaryFile2ContainerComponent } from '@alfa-client/binary-file';
import { ConvertForDataTestPipe, ConvertProblemDetailToErrorMessagesPipe, ProblemDetail } from '@alfa-client/tech-shared';
import {
  existsAsHtmlElement,
  getElementComponentFromFixtureByCss,
  notExistsAsHtmlElement,
  triggerEvent,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { AttachmentComponent, AttachmentWrapperComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { createBescheidAttachments } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { createProblemDetail } from '../../../../../../../tech-shared/test/error';
import { BescheidWizardAttachmentFilesComponent } from './bescheid-wizard-attachment-files.component';

describe('BescheidWizardAttachmentFileComponent', () => {
  let component: BescheidWizardAttachmentFilesComponent;
  let fixture: ComponentFixture<BescheidWizardAttachmentFilesComponent>;

  const convertForDataTest: ConvertForDataTestPipe = new ConvertForDataTestPipe();
  const convertProblemDetailsToErrorMessage: ConvertProblemDetailToErrorMessagesPipe =
    new ConvertProblemDetailToErrorMessagesPipe();

  const attachments: BescheidAttachments = createBescheidAttachments();

  const binaryFileContainerTestId: string = getDataTestIdOf(
    convertForDataTest.transform(attachments.items[0].name) + '-file2-container',
  );
  const attachmentUploadTestId: string = getDataTestIdOf('attachment-upload-in-progress');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardAttachmentFilesComponent,
        MockComponent(BinaryFile2ContainerComponent),
        MockComponent(AttachmentComponent),
        MockComponent(AttachmentWrapperComponent),
        ConvertForDataTestPipe,
        ConvertProblemDetailToErrorMessagesPipe,
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardAttachmentFilesComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      expect(component.upload).toEqual(createEmptyUploadInProgress());
      expect(component.attachments).toEqual(createEmptyBescheidAttachments().items);
    });

    describe('set attachments', () => {
      it('should set attachments', () => {
        component.attachments = attachments;

        expect(component.attachments).toEqual(attachments.items);
      });

      it('should set upload', () => {
        component.attachments = attachments;

        expect(component.upload).toEqual(attachments.upload);
      });
    });
  });

  describe('template', () => {
    describe('attachment binary file container', () => {
      it('should exists', () => {
        component.attachments = attachments;

        fixture.detectChanges();

        existsAsHtmlElement(fixture, binaryFileContainerTestId);
      });

      it('should have been called with inputs', () => {
        component.attachments = attachments;

        fixture.detectChanges();
        const binaryFileComponent: BinaryFile2ContainerComponent =
          getElementComponentFromFixtureByCss<BinaryFile2ContainerComponent>(fixture, binaryFileContainerTestId);

        expect(binaryFileComponent.file).toEqual(attachments.items[0]);
        expect(binaryFileComponent.deletable).toEqual(component.deletable);
      });

      describe('output', () => {
        describe('startDelete', () => {
          it('should emit', () => {
            component.attachments = attachments;
            component.delete.emit = jest.fn();

            fixture.detectChanges();

            triggerEvent({
              fixture,
              elementSelector: binaryFileContainerTestId,
              name: 'startDelete',
              data: attachments.items[0],
            });

            expect(component.delete.emit).toHaveBeenCalledWith(attachments.items[0]);
          });
        });
      });
    });

    describe('upload attachment', () => {
      it('should exists on loading', () => {
        component.attachments = { ...attachments, upload: { ...attachments.upload, loading: true, error: null } };

        fixture.detectChanges();

        existsAsHtmlElement(fixture, attachmentUploadTestId);
      });

      it('should exists on error', () => {
        component.attachments = {
          ...attachments,
          upload: { ...attachments.upload, loading: false, error: createProblemDetail() },
        };

        fixture.detectChanges();

        existsAsHtmlElement(fixture, attachmentUploadTestId);
      });

      it('should NOT exists', () => {
        component.attachments = {
          ...attachments,
          upload: { ...attachments.upload, loading: false, error: null },
        };

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, attachmentUploadTestId);
      });

      it('should have been called with inputs', () => {
        component.attachments = attachments;

        fixture.detectChanges();
        const attachmentComponent: AttachmentComponent = getElementComponentFromFixtureByCss<AttachmentComponent>(
          fixture,
          attachmentUploadTestId,
        );

        expect(attachmentComponent.loadingCaption).toEqual(attachments.upload.fileName);
        expect(attachmentComponent.errorMessages).toEqual(
          convertProblemDetailsToErrorMessage.transform(attachments.upload.error as ProblemDetail),
        );
        expect(attachmentComponent.isLoading).toEqual(attachments.upload.loading);
      });
    });
  });
});
