import { BescheidAttachments, BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidAttachments } from '../../../../../../bescheid-shared/src/test/bescheid';
import { createBinaryFileResource } from '../../../../../../binary-file-shared/test/binary-file';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { BescheidWizardAttachmentFilesComponent } from './attachment-files/bescheid-wizard-attachment-files.component';
import { BescheidWizardAttachmentFilesContainerComponent } from './bescheid-wizard-attachment-files-container.component';

describe('BescheidWizardAttachmentFileContainerComponent', () => {
  let component: BescheidWizardAttachmentFilesContainerComponent;
  let fixture: ComponentFixture<BescheidWizardAttachmentFilesContainerComponent>;

  const attachmentsFilesTestId: string = getDataTestIdOf('bescheid-attachments');

  const attachments: BescheidAttachments = createBescheidAttachments();

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardAttachmentFilesContainerComponent, MockComponent(BescheidWizardAttachmentFilesComponent)],
      providers: [{ provide: BescheidService2, useValue: bescheidService }],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardAttachmentFilesContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('ngOnInit', () => {
      it('should set attachments', () => {
        bescheidService.getAttachments.mockReturnValue(of(attachments));

        component.ngOnInit();

        expect(component.attachments$).toBeObservable(singleColdCompleted(attachments));
      });

      it('should set active step', () => {
        bescheidService.getActiveStep.mockReturnValue(of(BescheidWizardStep.BescheidVersenden));

        component.ngOnInit();

        expect(component.activeStep$).toBeObservable(singleColdCompleted(BescheidWizardStep.BescheidVersenden));
      });
    });

    describe('deleteAttachment', () => {
      it('should call service', () => {
        component.deleteAttachment = jest.fn();
        const binaryFileResource: BinaryFileResource = createBinaryFileResource();

        component.deleteAttachment(binaryFileResource);

        expect(component.deleteAttachment).toHaveBeenCalledWith(binaryFileResource);
      });
    });
  });

  describe('template', () => {
    describe('attachment files', () => {
      function getComponent(): BescheidWizardAttachmentFilesComponent {
        return getElementComponentFromFixtureByCss<BescheidWizardAttachmentFilesComponent>(fixture, attachmentsFilesTestId);
      }

      it('should exists', () => {
        existsAsHtmlElement(fixture, attachmentsFilesTestId);
      });

      it('should have been called with attachments', () => {
        component.attachments$ = of(attachments);

        fixture.detectChanges();

        expect(getComponent().attachments).toEqual(attachments);
      });

      it('should have been called with deletable true', () => {
        component.activeStep$ = of(BescheidWizardStep.DokumenteHochladen);

        fixture.detectChanges();

        expect(getComponent().deletable).toEqual(true);
      });

      it('should have been called with deletable false', () => {
        component.activeStep$ = of(BescheidWizardStep.BescheidVersenden);

        fixture.detectChanges();

        expect(getComponent().deletable).toEqual(false);
      });

      describe('output', () => {
        describe('delete', () => {
          it('should call handler', () => {
            const binaryFileResource: BinaryFileResource = createBinaryFileResource();
            component.deleteAttachment = jest.fn();

            triggerEvent({ fixture, elementSelector: attachmentsFilesTestId, name: 'delete', data: binaryFileResource });

            expect(component.deleteAttachment).toHaveBeenCalledWith(binaryFileResource);
          });
        });
      });
    });
  });
});
