import { BescheidLinkRel, BescheidResource, BescheidWizardDialogResult, Wizard } from '@alfa-client/bescheid-shared';
import { CommandResource, tapOnCommandSuccessfullyDone, tapOnFailedCommand } from '@alfa-client/command-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { DialogRef } from '@angular/cdk/dialog';
import { Component, inject, Input } from '@angular/core';
import { Observable, of } from 'rxjs';
import { BescheidFormService } from '../../../../bescheid.formservice';

@Component({
  selector: 'alfa-bescheid-wizard-bescheid-versenden-senden',
  templateUrl: './bescheid-wizard-bescheid-versenden-senden.component.html',
})
export class BescheidWizardBescheidVersendenSendenComponent {
  @Input() bescheidResource: BescheidResource;
  @Input() wizard: Wizard;

  public readonly formService: BescheidFormService = inject(BescheidFormService);
  private readonly dialogRef = inject(DialogRef<BescheidWizardDialogResult>);

  public submitStateResource$: Observable<StateResource<CommandResource>> = of(createEmptyStateResource<CommandResource>());

  public focusBetreff: boolean = false;
  public focusNachricht: boolean = false;

  public readonly bescheidLinkRel = BescheidLinkRel;
  public readonly formServiceClass = BescheidFormService;

  public submit(): void {
    this._resetFocus();
    this.submitStateResource$ = this.formService.submit().pipe(
      tapOnFailedCommand(() => this._focusToFirstInvalidControl()),
      tapOnCommandSuccessfullyDone(() => this.dialogRef.close({ reloadVorgang: true })),
    );
  }

  _focusToFirstInvalidControl(): void {
    if (this.formService.isBetreffInvalid()) {
      this.focusBetreff = true;
    } else if (this.formService.isNachrichtInvalid()) {
      this.focusNachricht = true;
    }
  }

  _resetFocus(): void {
    this.focusBetreff = false;
    this.focusNachricht = false;
  }
}
