import { BescheidDocument, BescheidResource } from '@alfa-client/bescheid-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidDocument, createBescheidResource } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { BescheidWizardCreateDocumentButtonContainerComponent } from './bescheid-wizard-create-document-button-container.component';
import { BescheidWizardCreateDocumentButtonComponent } from './create-document-button/bescheid-wizard-create-document-button.component';

describe('BescheidWizardCreateDocumentButtonContainerComponent', () => {
  let component: BescheidWizardCreateDocumentButtonContainerComponent;
  let fixture: ComponentFixture<BescheidWizardCreateDocumentButtonContainerComponent>;

  const buttonTestId: string = getDataTestIdOf('bescheid-wizard-create-button');

  const bescheidDocument: BescheidDocument = createBescheidDocument();
  const bescheidResource: BescheidResource = createBescheidResource();

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardCreateDocumentButtonContainerComponent,
        MockComponent(BescheidWizardCreateDocumentButtonComponent),
      ],
      providers: [{ provide: BescheidService2, useValue: bescheidService }],
    }).compileComponents();

    createComponent();
  });

  function createComponent() {
    fixture = TestBed.createComponent(BescheidWizardCreateDocumentButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  }

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));
      createComponent();

      expect(component.bescheidDocument$).toBeObservable(singleColdCompleted(bescheidDocument));
    });

    describe('createBescheidDocument', () => {
      it('should call service', () => {
        component.createBescheidDocument();

        expect(bescheidService.createBescheidDocument).toHaveBeenCalledWith(component.bescheidResource);
      });
    });
  });

  describe('template', () => {
    describe('create button', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, buttonTestId);
      });

      it('should have been called with inputs', () => {
        bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));
        createComponent();
        component.bescheidResource = bescheidResource;

        fixture.detectChanges();

        const buttonComponent: BescheidWizardCreateDocumentButtonComponent =
          getElementComponentFromFixtureByCss<BescheidWizardCreateDocumentButtonComponent>(fixture, buttonTestId);

        expect(buttonComponent.bescheidResource).toEqual(bescheidResource);
        expect(buttonComponent.bescheidDocument).toEqual(bescheidDocument);
      });

      describe('output', () => {
        describe('clickEmitter', () => {
          it('should call handler', () => {
            component.createBescheidDocument = jest.fn();

            triggerEvent({ fixture, elementSelector: buttonTestId, name: 'clickEmitter' });

            expect(component.createBescheidDocument).toHaveBeenCalled();
          });
        });
      });
    });
  });
});
