import { BescheidDocument, BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, Mock, mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidDocument } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { BescheidFormService } from '../../bescheid.formservice';
import { BescheidWizardDocumentFileContainerComponent } from './bescheid-wizard-document-file-container.component';
import { BescheidWizardDocumentFileComponent } from './document-file/bescheid-wizard-document-file.component';

describe('BescheidWizardDocumentFileContainerComponent', () => {
  let component: BescheidWizardDocumentFileContainerComponent;
  let fixture: ComponentFixture<BescheidWizardDocumentFileContainerComponent>;

  const documentFileTestId: string = getDataTestIdOf('bescheid-document');

  const bescheidDocument: BescheidDocument = createBescheidDocument();

  let bescheidService: Mock<BescheidService2>;
  let formService: Mock<BescheidFormService>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
    formService = mock(BescheidFormService);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardDocumentFileContainerComponent, MockComponent(BescheidWizardDocumentFileComponent)],
      providers: [
        { provide: BescheidService2, useValue: bescheidService },
        { provide: BescheidFormService, useValue: formService },
      ],
    }).compileComponents();

    createComponent();
  });

  function createComponent() {
    fixture = TestBed.createComponent(BescheidWizardDocumentFileContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  }

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));
      bescheidService.getActiveStep.mockReturnValue(of(BescheidWizardStep.BescheidVersenden));

      createComponent();

      expect(component.bescheidDocument$).toBeObservable(singleColdCompleted(bescheidDocument));
      expect(component.activeStep$).toBeObservable(singleColdCompleted(BescheidWizardStep.BescheidVersenden));
    });

    describe('deleteBescheidDocument', () => {
      it('should call form service', () => {
        component.deleteBescheidDocument();

        expect(formService.clearBescheidDocumentFile).toHaveBeenCalled();
        expect(bescheidService.deleteBescheidDocument).toHaveBeenCalled();
      });
    });
  });

  describe('template', () => {
    describe('document file', () => {
      function getComponent(): BescheidWizardDocumentFileComponent {
        return getElementComponentFromFixtureByCss<BescheidWizardDocumentFileComponent>(fixture, documentFileTestId);
      }

      it('should exists', () => {
        existsAsHtmlElement(fixture, documentFileTestId);
      });

      it('should have been called with bescheid document', () => {
        bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));

        createComponent();
        fixture.detectChanges();

        expect(getComponent().bescheidDocument).toEqual(bescheidDocument);
      });

      it('should have been called with deletable true', () => {
        bescheidService.getActiveStep.mockReturnValue(of(BescheidWizardStep.DokumenteHochladen));

        createComponent();
        fixture.detectChanges();

        expect(getComponent().deletable).toEqual(true);
      });

      it('should have been called with deletable false', () => {
        bescheidService.getActiveStep.mockReturnValue(of(BescheidWizardStep.BescheidVersenden));

        createComponent();
        fixture.detectChanges();

        expect(getComponent().deletable).toEqual(false);
      });

      describe('output', () => {
        describe('deleteFile', () => {
          it('should call handler', () => {
            component.deleteBescheidDocument = jest.fn();

            triggerEvent({ fixture, elementSelector: documentFileTestId, name: 'deleteFile' });

            expect(component.deleteBescheidDocument).toHaveBeenCalled();
          });
        });
      });
    });
  });
});
