/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidDocument, BescheidResource, BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { Component, inject, Input, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';

@Component({
  selector: 'alfa-bescheid-wizard-dokumente-hochladen-container',
  templateUrl: './bescheid-wizard-dokumente-hochladen-container.component.html',
})
export class BescheidWizardDokumenteHochladenContainerComponent implements OnInit {
  @Input() bescheidResource: BescheidResource;

  private readonly bescheidService = inject(BescheidService2);

  public readonly bescheidDocument$: Observable<BescheidDocument> = this.bescheidService.getBescheidDocument();
  public isBescheidDocumentMissing: boolean = false;

  public readonly BescheidWizardStep = BescheidWizardStep;

  ngOnInit(): void {
    this.bescheidService.loadFiles(this.bescheidResource);
  }

  public onWeiterClick(): void {
    this.bescheidService.finishAddingAttachments();
    this.bescheidService.finishAddingBescheidDocument();
    this.bescheidService.setActiveStep(BescheidWizardStep.BescheidVersenden);
  }

  public onBescheidDocumentMissing(value: boolean): void {
    this.isBescheidDocumentMissing = value;
  }

  public onStepChange(step: BescheidWizardStep): void {
    this.bescheidService.setActiveStep(step);
  }
}
