/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { BescheidWizardAttachmentFilesContainerComponent } from '../../attachment-files-container/bescheid-wizard-attachment-files-container.component';
import { BescheidWizardDocumentFileContainerComponent } from '../../document-file-container/bescheid-wizard-document-file-container.component';
import { BescheidWizardDokumenteHochladenSummaryComponent } from './bescheid-wizard-dokumente-hochladen-summary.component';

describe('BescheidWizardDokumenteHochladenSummaryComponent', () => {
  let component: BescheidWizardDokumenteHochladenSummaryComponent;
  let fixture: ComponentFixture<BescheidWizardDokumenteHochladenSummaryComponent>;

  const missingBescheidErrorMessageTestId: string = getDataTestIdOf('missing-bescheid-document-error-message');
  const documentFileTestId: string = getDataTestIdOf('bescheid-document-file');
  const attachmentFilesTestId: string = getDataTestIdOf('bescheid-attachment-files');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardDokumenteHochladenSummaryComponent,
        MockComponent(BescheidWizardDocumentFileContainerComponent),
        MockComponent(BescheidWizardAttachmentFilesContainerComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardDokumenteHochladenSummaryComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('missing bescheid error message', () => {
      it('should exists', () => {
        component.isBescheidDocumentMissing = true;

        fixture.detectChanges();

        existsAsHtmlElement(fixture, missingBescheidErrorMessageTestId);
      });

      it('should NOT exists', () => {
        component.isBescheidDocumentMissing = false;

        fixture.detectChanges();

        notExistsAsHtmlElement(fixture, missingBescheidErrorMessageTestId);
      });
    });

    describe('document file', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, documentFileTestId);
      });
    });

    describe('attachment files', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, attachmentFilesTestId);
      });
    });
  });
});
