/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { BescheidWizardStepperComponent } from '../stepper/bescheid-wizard-stepper.component';
import { BescheidWizardSummaryComponent } from '../summary/bescheid-wizard-summary.component';
import { StepContentLayoutComponent } from './step-content-layout.component';

describe('StepContentLayoutComponent', () => {
  let component: StepContentLayoutComponent;
  let fixture: ComponentFixture<StepContentLayoutComponent>;

  const wizardStepper: string = getDataTestIdOf('wizard-stepper');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        StepContentLayoutComponent,
        MockComponent(BescheidWizardStepperComponent),
        MockComponent(BescheidWizardSummaryComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(StepContentLayoutComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('on stepper step change', () => {
    it('should emit', () => {
      component.stepChange.emit = jest.fn();

      triggerEvent({
        fixture,
        name: 'stepChange',
        elementSelector: wizardStepper,
        data: BescheidWizardStep.AntragBescheiden,
      });

      expect(component.stepChange.emit).toHaveBeenCalledWith(BescheidWizardStep.AntragBescheiden);
    });
  });
});
