import { createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { getElementComponentFromFixtureByCss, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { faker } from '@faker-js/faker';
import { FileUploadEditorComponent } from '@ods/component';
import { MockComponent } from 'ng-mocks';
import { createBinaryFileResource } from '../../../../../../../binary-file-shared/test/binary-file';
import { getDataTestIdOf } from '../../../../../../../tech-shared/test/data-test';
import { createFile } from '../../../../../../../tech-shared/test/file';
import { BescheidFormService } from '../../../bescheid.formservice';
import { BescheidWizardUploadAttachmentButtonComponent } from './bescheid-wizard-upload-attachment-button.component';

describe('BescheidWizardUploadAttachmentButtonComponent', () => {
  let component: BescheidWizardUploadAttachmentButtonComponent;
  let fixture: ComponentFixture<BescheidWizardUploadAttachmentButtonComponent>;

  const uploadEditorTestId: string = getDataTestIdOf('bescheid-wizard-upload-editor');

  let formService: BescheidFormService;

  beforeEach(() => {
    formService = new BescheidFormService(new FormBuilder(), null);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BescheidWizardUploadAttachmentButtonComponent, MockComponent(FileUploadEditorComponent)],
      providers: [{ provide: BescheidFormService, useValue: formService }],
      imports: [ReactiveFormsModule],
    }).compileComponents();

    fixture = TestBed.createComponent(BescheidWizardUploadAttachmentButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      expect(component.upload).toEqual(createEmptyStateResource());
      expect(component.fileUrls).toEqual([]);
    });
  });

  describe('template', () => {
    describe('upload editor', () => {
      it('should have been called with inputs', () => {
        component.upload = createStateResource(createBinaryFileResource());
        component.fileUrls = [faker.internet.url()];

        fixture.detectChanges();
        const uploadEditorComponent: FileUploadEditorComponent = getElementComponentFromFixtureByCss<FileUploadEditorComponent>(
          fixture,
          uploadEditorTestId,
        );

        expect(uploadEditorComponent.parentFormArrayName).toEqual(BescheidFormService.FIELD_ATTACHMENTS);
        expect(uploadEditorComponent.uploadInProgress).toEqual(component.upload);
        expect(uploadEditorComponent.fileLinkList).toEqual(component.fileUrls);
      });

      describe('output', () => {
        describe('newFile', () => {
          it('should emit', () => {
            component.uploadFile.emit = jest.fn();
            const file: File = createFile();

            triggerEvent({ fixture, elementSelector: uploadEditorTestId, name: 'newFile', data: file });

            expect(component.uploadFile.emit).toHaveBeenCalledWith(file);
          });
        });
      });
    });
  });
});
