import { BescheidDocument, BescheidResource } from '@alfa-client/bescheid-shared';
import { getElementComponentFromFixtureByCss, mock, Mock, triggerEvent } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BescheidService2 } from '../../../../../../bescheid-shared/src/lib/bescheid2.service';
import { createBescheidDocument, createBescheidResource } from '../../../../../../bescheid-shared/src/test/bescheid';
import { getDataTestIdOf } from '../../../../../../tech-shared/test/data-test';
import { createFile } from '../../../../../../tech-shared/test/file';
import { singleColdCompleted } from '../../../../../../tech-shared/test/marbles';
import { BescheidWizardUploadDocumentButtonContainerComponent } from './bescheid-wizard-upload-document-button-container.component';
import { BescheidWizardUploadDocumentButtonComponent } from './upload-document-button/bescheid-wizard-upload-document-button.component';

describe('BescheidWizardDokumentHochladenContainerButtonComponent', () => {
  let component: BescheidWizardUploadDocumentButtonContainerComponent;
  let fixture: ComponentFixture<BescheidWizardUploadDocumentButtonContainerComponent>;

  const uploadDocumentButtonTestId: string = getDataTestIdOf('bescheid-wizard-upload-document-button');

  const bescheidDocument: BescheidDocument = createBescheidDocument();

  let bescheidService: Mock<BescheidService2>;

  beforeEach(() => {
    bescheidService = mock(BescheidService2);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BescheidWizardUploadDocumentButtonContainerComponent,
        MockComponent(BescheidWizardUploadDocumentButtonComponent),
      ],
      providers: [{ provide: BescheidService2, useValue: bescheidService }],
    }).compileComponents();

    createComponent();
  });

  function createComponent() {
    fixture = TestBed.createComponent(BescheidWizardUploadDocumentButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  }

  describe('component', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    it('should set initial values', () => {
      bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));

      createComponent();

      expect(component.bescheidDocument$).toBeObservable(singleColdCompleted(bescheidDocument));
    });

    describe('uploadBescheidDocumentFile', () => {
      it('should call bescheid service', () => {
        const file: File = createFile();
        const bescheidResource: BescheidResource = createBescheidResource();
        component.bescheidResource = bescheidResource;

        component.uploadBescheidDocumentFile(file);

        expect(bescheidService.uploadBescheidDocument).toHaveBeenCalledWith(file, bescheidResource);
      });
    });
  });

  describe('template', () => {
    describe('upload document button', () => {
      it('should have been called with inputs', () => {
        const bescheidResource: BescheidResource = createBescheidResource();
        bescheidService.getBescheidDocument.mockReturnValue(of(bescheidDocument));
        createComponent();
        component.bescheidResource = bescheidResource;

        fixture.detectChanges();
        const uploadDocumentButtonComponent: BescheidWizardUploadDocumentButtonComponent =
          getElementComponentFromFixtureByCss<BescheidWizardUploadDocumentButtonComponent>(fixture, uploadDocumentButtonTestId);

        expect(uploadDocumentButtonComponent.bescheidResource).toEqual(bescheidResource);
        expect(uploadDocumentButtonComponent.bescheidDocument).toEqual(bescheidDocument);
      });

      describe('output', () => {
        describe('file', () => {
          it('should call handler', () => {
            component.uploadBescheidDocumentFile = jest.fn();
            const file: File = createFile();

            triggerEvent({ fixture, elementSelector: uploadDocumentButtonTestId, name: 'file', data: file });

            expect(component.uploadBescheidDocumentFile).toHaveBeenCalledWith(file);
          });
        });
      });
    });
  });
});
