import { BinaryFileResource, FileToDelete, UploadFile, UploadFileByIdentifier } from '@alfa-client/binary-file-shared';
import { isLoaded, StateResource } from '@alfa-client/tech-shared';
import { KeyValuePipe } from '@angular/common';
import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { FormGroupDirective, UntypedFormArray, UntypedFormControl } from '@angular/forms';
import { getUrl } from '@ngxp/rest';
import {
  BinaryFileListOrientation,
  BinaryFileListOrientationDirective,
} from '../../directive/binary-file-list-orientation/binary-file-list-orientation.directive';
import { FileUploadListItemComponent } from '../file-upload-list-item/file-upload-list-item.component';

@Component({
  selector: 'ods-file-upload-list',
  standalone: true,
  templateUrl: './file-upload-list.component.html',
  imports: [FileUploadListItemComponent, KeyValuePipe, BinaryFileListOrientationDirective],
})
export class FileUploadListComponent implements OnInit {
  @Input() parentFormArrayName: string;
  @Input() listOrientation: BinaryFileListOrientation;

  @Input() set uploadedFiles(value: UploadFileByIdentifier) {
    this._updateUploadItems(value);
  }

  @Output() delete: EventEmitter<string> = new EventEmitter();

  public uploadItems: UploadFileByIdentifier;

  _fileLinkControls: UntypedFormArray = new UntypedFormArray([]);
  _fileUrls: string[] = [];

  constructor(public parentForm: FormGroupDirective) {}

  ngOnInit(): void {
    this._fileLinkControls = this.parentForm.form.get(this.parentFormArrayName) as UntypedFormArray;
  }

  _updateUploadItems(uploadFiles: UploadFileByIdentifier): void {
    this.uploadItems = uploadFiles;
    this._fileUrls = Object.values(uploadFiles)
      .map((value: UploadFile) => value.uploadedFile)
      .filter(isLoaded)
      .map((stateResource: StateResource<BinaryFileResource>) => getUrl(stateResource.resource));
    this._updateForm();
  }

  _addFileUrl(binaryFileResource: BinaryFileResource): void {
    this._fileUrls = [...this._fileUrls, getUrl(binaryFileResource)];
    this._updateForm();
  }

  _updateForm(): void {
    this._fileLinkControls.clear();
    this._fileUrls.forEach((link: string) => this._fileLinkControls.push(new UntypedFormControl(link)));
  }

  public onDelete(fileToDelete: FileToDelete): void {
    this._fileUrls = this._fileUrls.filter((url: string) => url !== getUrl(fileToDelete.binaryFileResource));
    this._updateForm();
    this.delete.emit(fileToDelete.key);
  }
}
