import { BinaryFileService, ToUploadFile } from '@alfa-client/binary-file-shared';
import { ConvertForDataTestPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, getElementComponentFromFixtureByCss, mock, Mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { expect } from '@jest/globals';
import { getUrl, Resource } from '@ngxp/rest';
import { FileUploadButtonComponent, SpinnerIconComponent } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { createFileList } from '../../../../tech-shared/test/file';
import { singleColdCompleted } from '../../../../tech-shared/test/marbles';
import { createDummyResource } from '../../../../tech-shared/test/resource';
import { MultiFileUploadEditorComponent } from './multi-file-upload-editor.component';

describe('MultiFileUploadEditorComponent', () => {
  let component: MultiFileUploadEditorComponent;
  let fixture: ComponentFixture<MultiFileUploadEditorComponent>;

  const uploadLinkRel: string = 'upload';
  const uploadResource: Resource = createDummyResource([uploadLinkRel]);

  const buttonTestId: string = getDataTestIdOf('Ein_Label-file-upload-button');

  let binaryFileService: Mock<BinaryFileService>;

  beforeEach(() => {
    binaryFileService = mock(BinaryFileService);
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        MultiFileUploadEditorComponent,
        ConvertForDataTestPipe,
        MockComponent(SpinnerIconComponent),
        MockComponent(FileUploadButtonComponent),
      ],
      providers: [
        {
          provide: BinaryFileService,
          useValue: binaryFileService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(MultiFileUploadEditorComponent);
    component = fixture.componentInstance;
    component.uploadResource = uploadResource;
    component.uploadLinkRelation = uploadLinkRel;
    component.label = 'Ein Label';
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      it('should set upload in progress', () => {
        binaryFileService.isUploadInProgress = jest.fn().mockReturnValue(of(true));

        component.ngOnInit();

        expect(component.isUploadInProgress$).toBeObservable(singleColdCompleted(true));
      });
    });

    describe('onFilesUpload', () => {
      beforeEach(() => {
        component._uploadFiles = jest.fn();
      });

      it('should upload files', () => {
        const fileList: FileList = createFileList();

        component.onFilesUpload(fileList);

        expect(component._uploadFiles).toHaveBeenCalledWith(fileList);
      });
    });

    describe('_uploadFiles', () => {
      it('should call binary file service', () => {
        const fileList: FileList = createFileList();

        component._uploadFiles(fileList);

        expect(binaryFileService.uploadFileNew).toHaveBeenCalledWith({
          file: fileList.item(0),
          type: component.fileUploadType,
          uploadUrl: getUrl(uploadResource, uploadLinkRel),
        } as ToUploadFile);
      });
    });
  });

  describe('template', () => {
    describe('upload button', () => {
      it('should exists', () => {
        existsAsHtmlElement(fixture, buttonTestId);
      });

      it('should have inputs', () => {
        binaryFileService.isUploadInProgress = jest.fn().mockReturnValue(of(true));
        component.ngOnInit();

        fixture.detectChanges();
        const fileButtonComponent: FileUploadButtonComponent = getElementComponentFromFixtureByCss(fixture, buttonTestId);

        expect(fileButtonComponent.id).toEqual(component.uploadButtonId);
        expect(fileButtonComponent.accept).toEqual(component.accept);
        expect(fileButtonComponent.multi).toEqual(true);
        expect(fileButtonComponent.isLoading).toEqual(true);
      });
    });
  });
});
