import { BinaryFileModule } from '@alfa-client/binary-file';
import { BinaryFileService, FileUploadType } from '@alfa-client/binary-file-shared';
import { KOMMENTAR_UPLOADED_ATTACHMENTS } from '@alfa-client/kommentar-shared';
import { ConvertForDataTestPipe } from '@alfa-client/tech-shared';
import { AsyncPipe } from '@angular/common';
import { Component, HostListener, inject, Input, OnInit } from '@angular/core';
import { ControlContainer, FormGroupDirective, ReactiveFormsModule } from '@angular/forms';
import { getUrl, Resource } from '@ngxp/rest';
import { AttachmentIconComponent, FileUploadButtonComponent, SpinnerIconComponent } from '@ods/system';
import { uniqueId } from 'lodash-es';
import { Observable } from 'rxjs';

@Component({
  selector: 'ods-multi-file-upload-editor',
  templateUrl: './multi-file-upload-editor.component.html',
  viewProviders: [{ provide: ControlContainer, useExisting: FormGroupDirective }],
  standalone: true,
  imports: [
    AsyncPipe,
    FileUploadButtonComponent,
    AttachmentIconComponent,
    SpinnerIconComponent,
    ReactiveFormsModule,
    BinaryFileModule,
    ConvertForDataTestPipe,
  ],
})
export class MultiFileUploadEditorComponent implements OnInit {
  @Input() label: string = '';
  @Input() accept: string = '*/*';
  @Input() fileUploadType: FileUploadType;
  @Input() uploadResource: Resource;
  @Input() uploadLinkRelation: string;

  private readonly binaryFileService: BinaryFileService = inject(BinaryFileService);

  public isUploadInProgress$: Observable<boolean>;

  public readonly uploadButtonId: string = uniqueId();

  ngOnInit(): void {
    this.isUploadInProgress$ = this.binaryFileService.isUploadInProgress(KOMMENTAR_UPLOADED_ATTACHMENTS);
  }

  @HostListener('change', ['$event.target.files'])
  public onFilesUpload(fileList: FileList): void {
    this._uploadFiles(fileList);
  }

  _uploadFiles(fileList: FileList) {
    for (let i = 0; i < fileList.length; i++) {
      this.binaryFileService.uploadFileNew({
        file: fileList.item(i),
        type: this.fileUploadType,
        uploadUrl: getUrl(this.uploadResource, this.uploadLinkRelation),
      });
    }
  }
}
