/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { argsToTemplate, componentWrapperDecorator, moduleMetadata, type Meta, type StoryObj } from '@storybook/angular';

import { SaveIconComponent } from '../../icons/save-icon/save-icon.component';
import { UserIconComponent } from '../../icons/user-icon/user-icon.component';
import { DropdownMenuButtonItemComponent } from '../dropdown-menu-button-item/dropdown-menu-button-item.component';
import { DropdownMenuItemComponent } from '../dropdown-menu-item/dropdown-menu-item.component';
import { DropdownMenuTextItemComponent } from '../dropdown-menu-text-item/dropdown-menu-text-item.component';
import { DropdownMenuComponent } from './dropdown-menu.component';

const meta: Meta<DropdownMenuComponent> = {
  title: 'Dropdown menu/Dropdown menu',
  component: DropdownMenuComponent,
  decorators: [
    moduleMetadata({
      imports: [
        DropdownMenuComponent,
        DropdownMenuItemComponent,
        DropdownMenuButtonItemComponent,
        DropdownMenuTextItemComponent,
        SaveIconComponent,
        UserIconComponent,
      ],
    }),
    componentWrapperDecorator((story) => `<div class="flex justify-center mb-32">${story}</div>`),
  ],
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
};

export default meta;
type Story = StoryObj<DropdownMenuComponent>;

export const Button: Story = {
  args: { alignTo: 'left', label: '', buttonClass: '' },
  argTypes: {
    alignTo: {
      control: 'select',
      options: ['left', 'right'],
      table: {
        defaultValue: { summary: 'left' },
      },
    },
    buttonClass: { description: 'Tailwind class for button' },
    label: { description: 'Aria-label for button' },
  },
  render: (args) => ({
    props: args,
    template: `<ods-dropdown-menu ${argsToTemplate(args)}>
        <ods-user-icon button-content />
        <ods-dropdown-menu-button-item caption="Lorem" />
        <ods-dropdown-menu-button-item caption="Ipsum" />
        <ods-dropdown-menu-button-item caption="Dolor" />
      </ods-dropdown-menu>`,
  }),
};

export const ButtonLongText: Story = {
  render: (args) => ({
    props: args,
    template: `<ods-dropdown-menu ${argsToTemplate(args)}>
        <p button-content>Trigger menu</p>
        <ods-dropdown-menu-button-item caption="Lorem" />
        <ods-dropdown-menu-button-item caption="Lorem ipsum dolor sit amet" />
      </ods-dropdown-menu>`,
  }),
};

export const ButtonWithIcon: Story = {
  render: (args) => ({
    props: args,
    template: `<ods-dropdown-menu ${argsToTemplate(args)}>
        <p button-content>Trigger menu</p>
        <ods-dropdown-menu-button-item caption="Lorem">
          <ods-save-icon icon size="small" />
        </ods-dropdown-menu-button-item>
        <ods-dropdown-menu-button-item caption="Lorem ipsum dolor sit amet">
          <ods-save-icon icon size="small" />
        </ods-dropdown-menu-button-item>
      </ods-dropdown-menu>`,
  }),
};

export const StructuredContent: Story = {
  render: (args) => ({
    props: args,
    template: `<ods-dropdown-menu ${argsToTemplate(args)}>
        <p button-content>Trigger menu</p>
        <ods-dropdown-menu-text-item title="Item 1" description="The quick brown fox jumps over the lazy dog">
        </ods-dropdown-menu-text-item>
        <ods-dropdown-menu-text-item title="Item 2" description="The quick brown fox jumps over the lazy dog">
          <ods-save-icon icon size="large" />
        </ods-dropdown-menu-text-item>
        <ods-dropdown-menu-text-item title="Item 3" description="The quick brown fox jumps over the lazy dog">
          <ods-save-icon icon size="large" />
          <button additionalContent class="border">Button</button>
        </ods-dropdown-menu-text-item>
      </ods-dropdown-menu>`,
  }),
};

export const AnyContent: Story = {
  render: (args) => ({
    props: args,
    template: `<ods-dropdown-menu ${argsToTemplate(args)}>
        <p button-content>Trigger menu</p>
        <ods-dropdown-menu-item class="border-t">Item 1</ods-dropdown-menu-item>
        <ods-dropdown-menu-item class="border-t border-b"><ods-save-icon size="small" /> Text <ods-save-icon size="large" /></ods-dropdown-menu-item>
      </ods-dropdown-menu>`,
  }),
};
