import { HasLinkPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { ForwardVorgangIconComponent, TooltipDirective } from '@ods/system';
import { getDataTestIdAttributeOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent, MockDirective } from 'ng-mocks';
import { ForwardByOzgcloudButtonContainerComponent } from './forward-by-ozgcloud-button-container.component';

describe('ForwardByOzgcloudButtonContainerComponent', () => {
  let component: ForwardByOzgcloudButtonContainerComponent;
  let fixture: ComponentFixture<ForwardByOzgcloudButtonContainerComponent>;

  const iconButton: string = getDataTestIdAttributeOf('forward-by-ozgcloud-icon-button');
  const button: string = getDataTestIdAttributeOf('forward-by-ozgcloud-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ForwardByOzgcloudButtonContainerComponent, HasLinkPipe],
      declarations: [
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(ForwardVorgangIconComponent),
        MockDirective(TooltipDirective),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(ForwardByOzgcloudButtonContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('on existing link', () => {
    beforeEach(() => {
      component.vorgangWithEingang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.FORWARD_BY_OZGCLOUD]);
    });

    describe('show as icon button', () => {
      beforeEach(() => {
        component.showAsIconButton = true;
        fixture.detectChanges();
      });

      it('should hide button', () => {
        notExistsAsHtmlElement(fixture, button);
      });

      it('should show iconButton', () => {
        existsAsHtmlElement(fixture, iconButton);
      });
    });

    describe('show as button', () => {
      beforeEach(() => {
        component.showAsIconButton = false;
        fixture.detectChanges();
      });

      it('should hide iconButton', () => {
        notExistsAsHtmlElement(fixture, iconButton);
      });

      it('should show button', () => {
        existsAsHtmlElement(fixture, button);
      });
    });
  });

  describe('on missing link', () => {
    it('should hide button', () => {
      component.vorgangWithEingang = createVorgangWithEingangResource();

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, button);
    });

    it('should hide icon button', () => {
      component.vorgangWithEingang = createVorgangWithEingangResource();

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, iconButton);
    });
  });
});
