/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { doIfLoadingRequired, StateResource } from '@alfa-client/tech-shared';
import { UserProfileResource, UserProfileService } from '@alfa-client/user-profile-shared';
import { Injectable } from '@angular/core';
import { Store } from '@ngrx/store';
import { Observable } from 'rxjs';
import { filter } from 'rxjs/operators';
import { HistorieListResource } from './historie.model';

import * as HistorieActions from './historie.actions';
import * as HistorieSelectors from './historie.selectors';

@Injectable()
export class HistorieFacade {
  constructor(
    private readonly store: Store,
    private userProfileService: UserProfileService,
  ) {}

  public getHistorie(): Observable<StateResource<HistorieListResource>> {
    return this.store.select(HistorieSelectors.historieSelector).pipe(
      filter(
        (historieList: StateResource<HistorieListResource>) =>
          !doIfLoadingRequired(historieList, () => {
            this.store.dispatch(HistorieActions.loadHistorie());
          }),
      ),
    );
  }

  public reloadHistorie(): void {
    this.store.dispatch(HistorieActions.reloadHistorie());
  }

  public getAssignedTo(command: CommandResource): Observable<StateResource<UserProfileResource>> {
    return this.userProfileService.getAssignedUserProfile(command, 'assignedTo');
  }
}
