/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  ApiErrorAction,
  createEmptyStateResource,
  createErrorStateResource,
  createStateResource,
  StateResource,
} from '@alfa-client/tech-shared';
import { Action, createReducer, on } from '@ngrx/store';
import { HistorieListProps } from './historie.actions';
import { HistorieListResource } from './historie.model';

import * as HistorieActions from './historie.actions';

export const HISTORIE_FEATURE_KEY = 'HistorieState';

export interface HistorieState {
  historieList: StateResource<HistorieListResource>;
}

export interface HistoriePartialState {
  readonly [HISTORIE_FEATURE_KEY]: HistorieState;
}

export const initialState: HistorieState = {
  historieList: createEmptyStateResource<HistorieListResource>(),
};

const historieReducer = createReducer(
  initialState,
  on(HistorieActions.loadHistorie, (state: HistorieState) => ({
    ...state,
    historieList: { ...state.historieList, loading: true },
  })),
  on(HistorieActions.loadHistorieSuccess, (state: HistorieState, props: HistorieListProps) => ({
    ...state,
    historieList: createStateResource(props.historieList),
  })),
  on(HistorieActions.loadHistorieFailed, (state: HistorieState, props: ApiErrorAction) => ({
    ...state,
    historieList: createErrorStateResource(props.apiError),
  })),
  on(HistorieActions.reloadHistorie, (state: HistorieState) => ({
    ...state,
    historieList: { ...state.historieList, reload: true },
  })),
);

export function reducer(state: HistorieState, action: Action) {
  return historieReducer(state, action);
}
