/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, Input, OnInit } from '@angular/core';
import { CommandOrder, CommandResource } from '@alfa-client/command-shared';
import { CommandLinkRel } from 'libs/command-shared/src/lib/command.linkrel';
import { isEmpty, isNull } from 'lodash-es';
import { hasContent } from '@alfa-client/tech-shared';

@Component({
  selector: 'alfa-historie-item-aktenzeichen',
  templateUrl: './historie-item-aktenzeichen.component.html',
  styleUrls: ['./historie-item-aktenzeichen.component.scss'],
})
export class HistorieItemAktenzeichenComponent implements OnInit {
  @Input() command: CommandResource;

  headline: string;
  aktenzeichenDeleted = false;

  get aktenzeichen(): any {
    return this.command.body.aktenzeichen;
  }

  ngOnInit(): void {
    this.aktenzeichenDeleted = isEmpty(this.aktenzeichen);
    this.setHeadline();
  }

  setHeadline(): void {
    if (this.aktenzeichenDeleted) {
      this.headline = 'das Aktenzeichen gelöscht.';
    } else {
      this.headline = HISTORIE_TEXT_BY_KOMMENTAR_ORDER[this.command.order];
    }
  }
}

const HISTORIE_TEXT_BY_KOMMENTAR_ORDER: { [order: string]: string } = {
  [CommandOrder.SET_AKTENZEICHEN]: 'das Aktenzeichen geändert.',
};
