/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileListLinkRel, BinaryFileResource } from '@alfa-client/binary-file-shared';
import { CommandResource, tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { KOMMENTAR_UPLOADED_ATTACHMENTS, KommentarLinkRel, KommentarListLinkRel, KommentarListResource, KommentarResource, KommentarService, } from '@alfa-client/kommentar-shared';
import { createEmptyStateResource, getEmbeddedResources, StateResource } from '@alfa-client/tech-shared';
import { Component, EventEmitter, Input, OnChanges, Output } from '@angular/core';
import { isNil } from 'lodash-es';
import { Observable, of } from 'rxjs';
import { map } from 'rxjs/operators';
import { KommentarFormService } from './kommentar.formservice';

@Component({
  selector: 'alfa-kommentar-form',
  templateUrl: './kommentar-form.component.html',
  styleUrls: ['./kommentar-form.component.scss'],
  providers: [KommentarFormService],
})
export class KommentarFormComponent implements OnChanges {
  @Input() kommentar: KommentarResource;
  @Input() kommentarListStateResource: StateResource<KommentarListResource>;

  @Output() cancel: EventEmitter<void> = new EventEmitter();

  submitInProgress$: Observable<StateResource<CommandResource>> = of(createEmptyStateResource<CommandResource>());

  public readonly formServiceClass = KommentarFormService;
  public readonly kommentarListLinkRel = KommentarListLinkRel;
  public readonly KommentarLinkRel = KommentarLinkRel;
  public readonly KOMMENTAR_UPLOADED_ATTACHMENTS = KOMMENTAR_UPLOADED_ATTACHMENTS;

  attachments$: Observable<BinaryFileResource[]> = of([]);

  constructor(
    public formService: KommentarFormService,
    public kommentarService: KommentarService,
  ) {}

  ngOnChanges(): void {
    if (!isNil(this.kommentar)) {
      this.patch();
      this.updateAttachments();
    }
  }

  private updateAttachments() {
    this.attachments$ = this.kommentarService
      .getAttachments(this.kommentar)
      .pipe(map((stateResource) => getEmbeddedResources<BinaryFileResource>(stateResource, BinaryFileListLinkRel.FILE_LIST)));
  }

  patch(): void {
    this.formService.patch(this.kommentar);
  }

  public submit(): void {
    this.submitInProgress$ = <Observable<StateResource<CommandResource>>>(
      this.formService.submit().pipe(tapOnCommandSuccessfullyDone(() => this.kommentarService.clearUploadedFiles()))
    );
  }

  public onCancel(): void {
    this.kommentarService.clearUploadedFiles();
    this.cancel.emit();
  }
}
