/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import {
  PostfachMailLinkRel,
  PostfachMailListLinkRel,
  PostfachMailListResource,
  PostfachMailResource,
  PostfachService,
} from '@alfa-client/postfach-shared';
import { FormProvider, StateResource, isNotNil } from '@alfa-client/tech-shared';
import { Component, Input, OnDestroy } from '@angular/core';
import { hasLink } from '@ngxp/rest';
import { Observable, of } from 'rxjs';
import { PostfachMailFormservice } from '../postfach-mail.formservice';

@Component({
  selector: 'alfa-postfach-nachricht-attachment-container',
  templateUrl: './postfach-nachricht-attachment-container.component.html',
  styleUrls: ['./postfach-nachricht-attachment-container.component.scss'],
  viewProviders: [FormProvider],
})
export class PostfachNachrichtAttachmentContainerComponent implements OnDestroy {
  @Input() postfachNachricht: PostfachMailResource;

  postfachNachrichtListStateResource$: Observable<StateResource<PostfachMailListResource>>;
  attachments$: Observable<BinaryFileResource[]> = of<BinaryFileResource[]>([]);

  public readonly postfachMailListLinkRel = PostfachMailListLinkRel;
  public readonly formServiceClass = PostfachMailFormservice;

  constructor(private postfachService: PostfachService) {}

  ngOnInit(): void {
    this.postfachNachrichtListStateResource$ = this.postfachService.getPostfachMailListByVorgang();

    if (isNotNil(this.postfachNachricht)) {
      this.initAttachments();
    }
  }

  initAttachments(): void {
    if (hasLink(this.postfachNachricht, PostfachMailLinkRel.ATTACHMENTS)) {
      this.attachments$ = this.postfachService.getAttachments(this.postfachNachricht);
    }
  }

  ngOnDestroy(): void {
    this.postfachService.clearAttachmentList();
  }
}
