/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BinaryFileModule } from '@alfa-client/binary-file';
import { ON_PAGE, PostfachSharedModule } from '@alfa-client/postfach-shared';
import { ConvertForDataTestPipe, FormatDateWithTimePipe, HasLinkPipe, ToEmbeddedResourcesPipe } from '@alfa-client/tech-shared';
import {
  BackButtonComponent,
  CheckboxEnumEditorComponent,
  IconButtonWithSpinnerComponent,
  OzgcloudIconComponent,
  OzgcloudStrokedButtonWithSpinnerComponent,
  OzgcloudTextEditorComponent,
  SpinnerComponent,
  SubnavigationComponent,
  TextAreaEditorComponent,
} from '@alfa-client/ui';
import { UserProfileModule } from '@alfa-client/user-profile';
import { VorgangSharedUiModule } from '@alfa-client/vorgang-shared-ui';
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { MatIcon } from '@angular/material/icon';
import { RouterModule, Routes } from '@angular/router';
import { ButtonComponent, MailboxIconComponent, PlusIconComponent, TooltipDirective } from '@ods/system';
import { PostfachMailButtonContainerComponent } from './postfach-mail-button-container/postfach-mail-button-container.component';
import { PostfachMailButtonComponent } from './postfach-mail-button-container/postfach-mail-button/postfach-mail-button.component';
import { PostfachMailFormComponent } from './postfach-mail-form/postfach-mail-form.component';
import { PostfachNachrichtAttachmentContainerComponent } from './postfach-mail-form/postfach-nachricht-attachment-container/postfach-nachricht-attachment-container.component';
import { PostfachNachrichtReplyEditorContainerComponent } from './postfach-mail-form/postfach-nachricht-reply-editor-container/postfach-nachricht-reply-editor-container.component';
import { PostfachMailListContainerComponent } from './postfach-mail-list-container/postfach-mail-list-container.component';
import { PostfachMailListComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail-list.component';
import { IncommingMailComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/incomming-mail/incomming-mail.component';
import { OutgoingMailErrorContainerComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/outgoing-mail/outgoing-mail-error-container/outgoing-mail-error-container.component';
import { OutgoingMailErrorComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/outgoing-mail/outgoing-mail-error-container/outgoing-mail-error/outgoing-mail-error.component';
import { OutgoingMailComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/outgoing-mail/outgoing-mail.component';
import { PostfachNachrichtEditButtonContainerComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/outgoing-mail/postfach-nachricht-edit-button-container/postfach-nachricht-edit-button-container.component';
import { PostfachMailAttachmentsComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/postfach-mail-attachments/postfach-mail-attachments.component';
import { PostfachMailDateComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/postfach-mail-date/postfach-mail-date.component';
import { PostfachMailComponent } from './postfach-mail-list-container/postfach-mail-list/postfach-mail/postfach-mail.component';
import { PostfachMailPdfButtonContainerComponent } from './postfach-mail-pdf-button-container/postfach-mail-pdf-button-container.component';
import { PostfachMailPdfButtonComponent } from './postfach-mail-pdf-button-container/postfach-mail-pdf-button/postfach-mail-pdf-button.component';
import { PostfachPageContainerComponent } from './postfach-page-container/postfach-page-container.component';
import { PostfachPageMailListComponent } from './postfach-page-container/postfach-page/postfach-page-mail-list/postfach-page-mail-list.component';
import { PostfachPageComponent } from './postfach-page-container/postfach-page/postfach-page.component';

const routes: Routes = [
  {
    path: 'postfach',
    component: PostfachPageContainerComponent,
    title: 'Nachrichten zum Vorgang | Alfa',
  },
];

@NgModule({
  imports: [
    CommonModule,
    RouterModule.forChild(routes),
    PostfachSharedModule,
    UserProfileModule,
    VorgangSharedUiModule,
    BinaryFileModule,
    OzgcloudStrokedButtonWithSpinnerComponent,
    HasLinkPipe,
    CheckboxEnumEditorComponent,
    ReactiveFormsModule,
    OzgcloudTextEditorComponent,
    TextAreaEditorComponent,
    MatIcon,
    OzgcloudIconComponent,
    FormatDateWithTimePipe,
    SpinnerComponent,
    ToEmbeddedResourcesPipe,
    ConvertForDataTestPipe,
    SubnavigationComponent,
    BackButtonComponent,
    IconButtonWithSpinnerComponent,
    ButtonComponent,
    PlusIconComponent,
    MailboxIconComponent,
    TooltipDirective,
  ],
  declarations: [
    PostfachMailListContainerComponent,
    PostfachMailButtonContainerComponent,
    PostfachMailFormComponent,
    PostfachMailListComponent,
    PostfachMailComponent,
    PostfachPageContainerComponent,
    IncommingMailComponent,
    OutgoingMailComponent,
    PostfachPageComponent,
    PostfachPageMailListComponent,
    OutgoingMailErrorComponent,
    PostfachMailDateComponent,
    OutgoingMailErrorContainerComponent,
    PostfachMailAttachmentsComponent,
    PostfachMailButtonComponent,
    PostfachMailPdfButtonContainerComponent,
    PostfachMailPdfButtonComponent,
    PostfachNachrichtEditButtonContainerComponent,
    PostfachNachrichtAttachmentContainerComponent,
    PostfachNachrichtReplyEditorContainerComponent,
  ],
  exports: [PostfachMailListContainerComponent, PostfachMailButtonContainerComponent, PostfachMailFormComponent],
  providers: [
    {
      provide: ON_PAGE,
      useValue: undefined,
    },
  ],
})
export class PostfachModule {}
