/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createKeydownKeyboardEvent } from 'libs/test-utils/src/lib/keyboard';
import {
  ARROW_DOWN_KEY,
  ARROW_UP_KEY,
  ENTER_KEY,
  ESCAPE_KEY,
  isArrowDownKey,
  isArrowUpKey,
  isEnterKey,
  isEscapeKey,
} from './keyboard.util';

describe('keyboard', () => {
  describe('isEscapeKey', () => {
    it('should return true', () => {
      const isEscape: boolean = isEscapeKey(createKeydownKeyboardEvent(ESCAPE_KEY));

      expect(isEscape).toBeTruthy();
    });

    it('should return false', () => {
      const isEscape: boolean = isEscapeKey(createKeydownKeyboardEvent(ENTER_KEY));

      expect(isEscape).toBeFalsy();
    });
  });

  describe('isEnterKey', () => {
    it('should return true', () => {
      const isEnter: boolean = isEnterKey(createKeydownKeyboardEvent(ENTER_KEY));

      expect(isEnter).toBeTruthy();
    });

    it('should return false', () => {
      const isEnter: boolean = isEnterKey(createKeydownKeyboardEvent(ESCAPE_KEY));

      expect(isEnter).toBeFalsy();
    });
  });
  describe('isArrowUpKey', () => {
    it('should return true', () => {
      const isArrowUp: boolean = isArrowUpKey(createKeydownKeyboardEvent(ARROW_UP_KEY));

      expect(isArrowUp).toBeTruthy();
    });

    it('should return false', () => {
      const isArrowUp: boolean = isArrowUpKey(createKeydownKeyboardEvent(ESCAPE_KEY));

      expect(isArrowUp).toBeFalsy();
    });
  });
  describe('isArrowDownKey', () => {
    it('should return true', () => {
      const isArrowDown: boolean = isArrowDownKey(createKeydownKeyboardEvent(ARROW_DOWN_KEY));

      expect(isArrowDown).toBeTruthy();
    });

    it('should return false', () => {
      const isEnter: boolean = isArrowDownKey(createKeydownKeyboardEvent(ESCAPE_KEY));

      expect(isEnter).toBeFalsy();
    });
  });
});
