/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { RouterTestingModule } from '@angular/router/testing';
import { faker } from '@faker-js/faker';
import { ArrowBackIconComponent, ButtonComponent, TooltipDirective } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent, MockDirective } from 'ng-mocks';
import { BackButtonComponent } from './back-button.component';

describe('BackButtonComponent', () => {
  let component: BackButtonComponent;
  let fixture: ComponentFixture<BackButtonComponent>;

  const backButton: string = getDataTestIdOf('back-button');
  const linkToAsArray: string[] = [faker.word.adverb(), faker.word.adverb()];
  const linkToAsString: string = '/' + linkToAsArray.join('/');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        BackButtonComponent,
        MockComponent(ButtonComponent),
        MockComponent(ArrowBackIconComponent),
        MockDirective(TooltipDirective),
      ],
      imports: [RouterTestingModule],
    }).compileComponents();

    fixture = TestBed.createComponent(BackButtonComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('linkTo', () => {
    it('string path should set href attribute', () => {
      component.linkTo = linkToAsString;
      fixture.detectChanges();

      const backButtonElement: HTMLAnchorElement = getElementFromFixture(fixture, backButton);

      expect(backButtonElement).toHaveAttribute('href', component.linkTo);
    });

    it('empty string path should set href attribute to base url', () => {
      component.linkTo = '';
      fixture.detectChanges();

      const backButtonElement: HTMLAnchorElement = getElementFromFixture(fixture, backButton);

      expect(backButtonElement).toHaveAttribute('href', '/');
    });

    it('array path should set href attribute', () => {
      component.linkTo = linkToAsArray;
      fixture.detectChanges();

      const backButtonElement: HTMLAnchorElement = getElementFromFixture(fixture, backButton);

      expect(backButtonElement).toHaveAttribute('href', linkToAsString);
    });

    it('empty array path should href attribute to base url', () => {
      component.linkTo = [];
      fixture.detectChanges();

      const backButtonElement: HTMLAnchorElement = getElementFromFixture(fixture, backButton);

      expect(backButtonElement).toHaveAttribute('href', '/');
    });
  });
});
