/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { KommentarLinkRel, KommentarResource } from '@alfa-client/kommentar-shared';
import { mock } from '@alfa-client/test-utils';
import { UserProfileService } from '@alfa-client/user-profile-shared';
import { createKommentarResource } from 'libs/kommentar-shared/test/kommentar';
import { MockComponent } from 'ng-mocks';
import { UserIconComponent } from '../user-icon/user-icon.component';
import { UserProfileComponent } from '../user-profile/user-profile.component';
import { UserProfileInKommentarContainerComponent } from './user-profile-in-kommentar-container.component';

describe('UserProfileInKommentarContainerComponent', () => {
  let component: UserProfileInKommentarContainerComponent;
  let fixture: ComponentFixture<UserProfileInKommentarContainerComponent>;

  const userProfileService = mock(UserProfileService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        UserProfileInKommentarContainerComponent,
        MockComponent(UserIconComponent),
        MockComponent(UserProfileComponent),
      ],
      providers: [
        {
          provide: UserProfileService,
          useValue: userProfileService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(UserProfileInKommentarContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    const kommentar: KommentarResource = createKommentarResource([KommentarLinkRel.CREATED_BY]);

    it('should call service if link exist', () => {
      component.kommentar = kommentar;

      component.ngOnInit();

      expect(userProfileService.getAssignedUserProfile).toHaveBeenCalledWith(
        kommentar,
        KommentarLinkRel.CREATED_BY,
      );
    });

    it('should not call service if link is missing', () => {
      component.kommentar = { ...createKommentarResource() };

      component.ngOnInit();

      expect(userProfileService.getAssignedUserProfile).not.toHaveBeenCalledWith();
    });
  });
});
