/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  BescheidLinkRel,
  BescheidResource,
  BescheidService,
  UploadFileInProgress,
} from '@alfa-client/bescheid-shared';
import { BinaryFileResource } from '@alfa-client/binary-file-shared';
import { CommandResource, hasCommandError } from '@alfa-client/command-shared';
import { createEmptyStateResource, isNotNil, StateResource } from '@alfa-client/tech-shared';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { getUrl, hasLink } from '@ngxp/rest';

@Component({
  selector: 'alfa-vorgang-detail-bescheiden-result-dokument',
  templateUrl: './vorgang-detail-bescheiden-result-dokument.component.html',
})
export class VorgangDetailBescheidenResultDokumentComponent {
  static readonly CREATE_DOCUMENT_ERROR_MESSAGE: string =
    'Bescheiddokument konnte nicht erzeugt werden.';

  @Input() bescheidDocumentFile: StateResource<BinaryFileResource>;
  @Input() uploadBescheidDocumentInProgress: UploadFileInProgress = { loading: false };

  @Input() set createBescheidDocumentInProgress(
    commandStateResource: StateResource<CommandResource>,
  ) {
    this.createDocumentInProgess = commandStateResource;
    this.handleCreateBescheidDocumentCommandError(commandStateResource);
  }

  @Input() set bescheidDraftStateResource(bescheidStateResource: StateResource<BescheidResource>) {
    this.handleBescheidDocument(bescheidStateResource.resource);
  }

  @Input() public deletable: boolean;

  @Input() public showMissingBescheidDocumentError: boolean;
  @Output() deleteFile: EventEmitter<void> = new EventEmitter<void>();

  createDocumentErrorMessages: string[] = [];
  createDocumentInProgess: StateResource<CommandResource> = createEmptyStateResource();
  hasCreateDocumentError: boolean = false;

  constructor(private bescheidService: BescheidService) {}

  handleBescheidDocument(bescheid: BescheidResource): void {
    if (hasLink(bescheid, BescheidLinkRel.BESCHEID_DOCUMENT)) {
      this.bescheidService.loadBescheidDocumentByUri(
        getUrl(bescheid, BescheidLinkRel.BESCHEID_DOCUMENT),
      );
    }
  }

  handleCreateBescheidDocumentCommandError(
    commandStateResource: StateResource<CommandResource>,
  ): void {
    this.hasCreateDocumentError =
      isNotNil(commandStateResource.resource) && hasCommandError(commandStateResource.resource);
    if (this.hasCreateDocumentError) {
      this.createDocumentErrorMessages = [
        VorgangDetailBescheidenResultDokumentComponent.CREATE_DOCUMENT_ERROR_MESSAGE,
      ];
    } else {
      this.createDocumentErrorMessages = [];
    }
  }
}
