/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidResource, BescheidService } from '@alfa-client/bescheid-shared';
import { PostfachService } from '@alfa-client/postfach-shared';
import { Mock, dispatchEventFromFixture, mock, useFromMock } from '@alfa-client/test-utils';
import { OzgcloudDialogService } from '@alfa-client/ui';
import { VorgangService, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { DIALOG_DATA, DialogRef } from '@angular/cdk/dialog';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule, UntypedFormBuilder } from '@angular/forms';
import { MatIcon } from '@angular/material/icon';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { Subscription, of } from 'rxjs';
import { createBescheidResource } from '../../../../../bescheid-shared/src/test/bescheid';
import { createVorgangWithEingangResource } from '../../../../../vorgang-shared/test/vorgang';
import { BescheidenFormService } from './bescheiden.formservice';
import { VorgangDetailBescheidenResultComponent } from './vorgang-detail-bescheiden-result/vorgang-detail-bescheiden-result.component';
import { VorgangDetailBescheidenAbbrechenButtonComponent } from './vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-abbrechen-button/vorgang-detail-bescheiden-abbrechen-button.component';
import { VorgangDetailBescheidenAbbrechenDialogComponent } from './vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps-content/vorgang-detail-bescheiden-abbrechen-dialog/vorgang-detail-bescheiden-abbrechen-dialog.component';
import { VorgangDetailBescheidenStepsComponent } from './vorgang-detail-bescheiden-steps/vorgang-detail-bescheiden-steps.component';
import { VorgangDetailBescheidenComponent } from './vorgang-detail-bescheiden.component';

describe('VorgangDetailBescheidenComponent', () => {
  let component: VorgangDetailBescheidenComponent;
  let fixture: ComponentFixture<VorgangDetailBescheidenComponent>;

  let bescheidService: Mock<BescheidService>;
  let vorgangService: Mock<VorgangService>;
  let formService: BescheidenFormService;
  let postfachService: Mock<PostfachService>;
  let ozgcloudDialogService: Mock<OzgcloudDialogService>;

  let vorgangWithEingangResource: VorgangWithEingangResource;
  let bescheidDraftResource: BescheidResource;

  const bescheidenResult: string = getDataTestIdOf('bescheiden-result');

  beforeEach(async () => {
    bescheidService = mock(BescheidService);
    vorgangService = mock(VorgangService);
    formService = new BescheidenFormService(new UntypedFormBuilder(), useFromMock(bescheidService));
    postfachService = mock(PostfachService);
    ozgcloudDialogService = mock(OzgcloudDialogService);

    vorgangWithEingangResource = createVorgangWithEingangResource();
    bescheidDraftResource = createBescheidResource();

    TestBed.overrideComponent(VorgangDetailBescheidenComponent, {
      set: {
        providers: [
          {
            provide: BescheidenFormService,
            useValue: formService,
          },
        ],
      },
    });
    await TestBed.configureTestingModule({
      declarations: [
        VorgangDetailBescheidenComponent,
        MockComponent(VorgangDetailBescheidenStepsComponent),
        MockComponent(VorgangDetailBescheidenResultComponent),
        MockComponent(VorgangDetailBescheidenAbbrechenButtonComponent),
        MockComponent(MatIcon),
      ],
      providers: [
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
        {
          provide: VorgangService,
          useValue: vorgangService,
        },
        {
          provide: DialogRef,
          useValue: { keydownEvents: of(KeyboardEvent), close: jest.fn(), disableClose: false },
        },
        {
          provide: DIALOG_DATA,
          useValue: { vorgangWithEingangResource, bescheidDraftResource },
        },
        {
          provide: PostfachService,
          useValue: postfachService,
        },
        {
          provide: OzgcloudDialogService,
          useValue: ozgcloudDialogService,
        },
      ],
      imports: [ReactiveFormsModule],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangDetailBescheidenComponent);
    component = fixture.componentInstance;

    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should set vorgang on form service', () => {
      const setVorgangWithEingangResource = (formService.setVorgangWithEingangResource = jest.fn());

      component.ngOnInit();

      expect(setVorgangWithEingangResource).toHaveBeenCalledWith(vorgangWithEingangResource);
    });

    it('should patch values', () => {
      const patchValues = (formService.patchValues = jest.fn());

      component.ngOnInit();

      expect(patchValues).toHaveBeenCalledWith(bescheidDraftResource);
    });

    it('should call handleEscapeKey', () => {
      component.handleEscapeKey = jest.fn();

      component.ngOnInit();

      expect(component.handleEscapeKey).toHaveBeenCalled();
    });
  });

  describe('handleEscapeKey', () => {
    it('should subscribe to dialogRef.keydownEvents', () => {
      component.handleEscapeKey();

      expect(component.keydownEventsSubscription).toBeInstanceOf(Subscription);
    });
  });

  describe('ngOnDestroy', () => {
    it('should unsubscribe keydownEventsSubscription', () => {
      component.keydownEventsSubscription = new Subscription();
      jest.spyOn(component.keydownEventsSubscription, 'unsubscribe');

      component.ngOnDestroy();

      expect(component.keydownEventsSubscription.unsubscribe).toHaveBeenCalled();
    });
  });

  describe('onClose', () => {
    it('should call dialogRef.close', () => {
      component.onClose();

      expect(component.dialogRef.close).toHaveBeenCalled();
    });

    it('should call vorgang service to reload current vorgang', () => {
      component.onClose();

      expect(vorgangService.reloadCurrentVorgang).toHaveBeenCalled();
    });

    it('should reload postfach mail list', () => {
      component.onClose();

      expect(postfachService.setPostfachMailOnReload).toHaveBeenCalled();
    });
  });

  describe('close dialog on bescheiden result', () => {
    it('should close dialog ref', () => {
      dispatchEventFromFixture(fixture, bescheidenResult, 'closeDialog');

      expect(component.dialogRef.close).toHaveBeenCalled();
    });
  });

  describe('cancelWizard', () => {
    it('should call ozgcloudDialogService.open', () => {
      component.cancelWizard();

      expect(ozgcloudDialogService.openInCallingComponentContext).toHaveBeenCalledWith(
        VorgangDetailBescheidenAbbrechenDialogComponent,
        component.viewContainerRef,
      );
    });
  });
});
