/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { VorgangResource } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { TooltipDirective } from '@ods/system';
import { createVorgangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockDirective } from 'ng-mocks';
import { VORGANG_KEIN_AKTENZEICHEN_ZUGEWIESEN } from '../vorgang-util';
import { AktenzeichenComponent } from './aktenzeichen.component';

describe('AktenzeichenComponent', () => {
  let component: AktenzeichenComponent;
  let fixture: ComponentFixture<AktenzeichenComponent>;

  const vorgang: VorgangResource = createVorgangResource();

  const aktenzeichen: string = '[data-test-id="aktenzeichen"]';

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [AktenzeichenComponent, MockDirective(TooltipDirective)],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AktenzeichenComponent);
    component = fixture.componentInstance;
    component.vorgang = vorgang;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('aktenzeichen', () => {
    it('should show default message', () => {
      component.vorgang = { ...vorgang, aktenzeichen: null };

      fixture.detectChanges();
      const aktenzeichenMessage: HTMLElement = fixture.nativeElement.querySelector(aktenzeichen);

      expect(aktenzeichenMessage.innerHTML.trim()).toBe(VORGANG_KEIN_AKTENZEICHEN_ZUGEWIESEN);
    });

    it('should show aktenzeichen', () => {
      component.vorgang = vorgang;

      fixture.detectChanges();
      const aktenzeichenMessage: HTMLElement = fixture.nativeElement.querySelector(aktenzeichen);

      expect(aktenzeichenMessage.textContent.trim()).toBe(vorgang.aktenzeichen);
    });
  });
});
